(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    217981,       5617]
NotebookOptionsPosition[    141698,       3956]
NotebookOutlinePosition[    207356,       5277]
CellTagsIndexPosition[    207313,       5274]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Defining a parametric distribution", "Title",
 CellChangeTimes->{{3.52665871596491*^9, 3.5266587278811016`*^9}, {
  3.5268316374963827`*^9, 3.526831657153348*^9}, {3.5268325130709314`*^9, 
  3.5268325182924533`*^9}}],

Cell["Oleksandr Pavlyk, Wolfram Research Inc.", "Subsubtitle",
 CellChangeTimes->{{3.5268315106026945`*^9, 3.5268315192935634`*^9}}],

Cell[TextData[{
 "\nThis notebook provides an example of plugging a parametric distribution \
into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 8\[CloseCurlyQuote]s probability and statistics framework. It is a \
comprehensive implementation, including RNG and parameter estimation."
}], "Text",
 CellChangeTimes->{{3.526831531973831*^9, 3.526831577249358*^9}, 
   3.5268316669893312`*^9, 3.5268358593261538`*^9, {3.527995040002433*^9, 
   3.527995070304433*^9}}],

Cell["\<\
The distribution we are about to define is equivalent to the following:\
\>", "Text",
 CellChangeTimes->{{3.526831583492983*^9, 3.5268316234729805`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExampleDistribution", "[", "a", "]"}], "\[Equal]", 
  RowBox[{"ProbabilityDistribution", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"4", 
       RowBox[{"a", "^", "2"}]}], 
      SuperscriptBox["\[Pi]", "2"]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["x", 
        RowBox[{"a", "-", "1"}]], 
       RowBox[{"Log", "[", "x", "]"}]}], 
      RowBox[{
       SuperscriptBox["x", 
        RowBox[{"2", "a"}]], "-", "1"}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"a", ">", "0"}]}]}], "]"}]}]], "DisplayFormula",
 CellChangeTimes->{{3.5266587511544285`*^9, 3.5266587959909115`*^9}, 
   3.526659076480958*^9, {3.5266591500773168`*^9, 3.5266591547027793`*^9}}],

Cell[TextData[{
 StyleBox["N.B.",
  FontWeight->"Bold"],
 ": Cells with definitions are marked as initialization cells."
}], "Text",
 CellChangeTimes->{{3.5268321187034984`*^9, 3.52683215182481*^9}}],

Cell[CellGroupData[{

Cell["Distribution properties needed for implementation", "Section",
 CellChangeTimes->{{3.5270103403393435`*^9, 3.527010358134123*^9}}],

Cell[CellGroupData[{

Cell["Symmetries", "Subsection",
 CellChangeTimes->{{3.5270103647927885`*^9, 3.527010367148024*^9}}],

Cell[CellGroupData[{

Cell["Reciprocation", "Subsubsection",
 CellChangeTimes->{{3.5270105001683245`*^9, 3.527010502763584*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"f", "[", 
     FractionBox["1", "x"], "]"}]}], 
   FractionBox["1", 
    SuperscriptBox["x", "2"]]}], "\[Equal]", 
  RowBox[{"f", "[", "x", "]"}]}]], "DisplayFormula",
 CellChangeTimes->{{3.5270104462789364`*^9, 3.5270104826095695`*^9}}],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"4", 
       RowBox[{"a", "^", "2"}]}], 
      SuperscriptBox["\[Pi]", "2"]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["x", 
        RowBox[{"a", "-", "1"}]], 
       RowBox[{"Log", "[", "x", "]"}]}], 
      RowBox[{
       SuperscriptBox["x", 
        RowBox[{"2", "a"}]], "-", "1"}]], 
     RowBox[{"Dt", "[", "x", "]"}]}], "/.", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"1", "/", "x"}]}]}], ",", 
   RowBox[{"x", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5270103719895086`*^9, 3.5270103904943585`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"4", 
      RowBox[{"a", "^", "2"}]}], 
     SuperscriptBox["\[Pi]", "2"]], 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", 
       RowBox[{"a", "-", "1"}]], 
      RowBox[{"Log", "[", "x", "]"}]}], 
     RowBox[{
      SuperscriptBox["x", 
       RowBox[{"2", "a"}]], "-", "1"}]], 
    RowBox[{"Dt", "[", "x", "]"}]}], "\[Equal]", 
   RowBox[{"-", "%"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.5270104210064096`*^9, 3.5270104274810567`*^9}}],

Cell["This implies:", "Text",
 CellChangeTimes->{{3.5270107354838543`*^9, 3.527010743784684*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Probability", "[", " ", 
   RowBox[{
    RowBox[{"z", "\[LessEqual]", "x"}], ",", 
    RowBox[{"z", "\[Distributed]", 
     RowBox[{"ExampleDistribution", "[", "a", "]"}]}]}], "]"}], "\[Equal]", 
  RowBox[{"Probability", "[", 
   RowBox[{
    RowBox[{"z", "\[GreaterEqual]", 
     FractionBox["1", "x"]}], ",", 
    RowBox[{"z", "\[Distributed]", 
     RowBox[{"ExampleDistribution", "[", "a", "]"}]}]}], 
   "]"}]}]], "DisplayFormula",
 CellChangeTimes->{{3.527010688316138*^9, 3.527010725301836*^9}},
 Background->RGBColor[0.87, 0.94, 1]]
}, Closed]],

Cell[CellGroupData[{

Cell["Powers", "Subsubsection",
 CellChangeTimes->{{3.527010513730681*^9, 3.5270105148457923`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["f", "a"], "[", 
    SuperscriptBox["x", "b"], "]"}], 
   RowBox[{"(", 
    RowBox[{"b", " ", 
     SuperscriptBox["x", 
      RowBox[{"b", "-", "1"}]]}], ")"}]}], "\[Equal]", 
  RowBox[{
   SubscriptBox["f", 
    RowBox[{"a", " ", "b"}]], "[", "x", "]"}]}]], "DisplayFormula",
 CellChangeTimes->{{3.5270105264759555`*^9, 3.5270105708513927`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"4", 
        RowBox[{"a", "^", "2"}]}], 
       SuperscriptBox["\[Pi]", "2"]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["x", 
         RowBox[{"a", "-", "1"}]], 
        RowBox[{"Log", "[", "x", "]"}]}], 
       RowBox[{
        SuperscriptBox["x", 
         RowBox[{"2", "a"}]], "-", "1"}]], 
      RowBox[{"Dt", "[", "x", "]"}]}], "/.", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{"x", "^", "b"}]}]}], ",", 
    RowBox[{
     RowBox[{"x", ">", "0"}], "&&", 
     RowBox[{"a", ">", "0"}], "&&", 
     RowBox[{"b", ">", "0"}]}]}], "]"}], "/.", 
  RowBox[{
   RowBox[{"Dt", "[", "b", "]"}], "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.5270105925335608`*^9, 3.5270106009504023`*^9}, {
  3.527010647652072*^9, 3.5270106563779445`*^9}}],

Cell[BoxData[
 RowBox[{"%", "==", 
  RowBox[{
   FractionBox[
    RowBox[{"4", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", " ", "b"}], ")"}], "^", "2"}]}], 
    SuperscriptBox["\[Pi]", "2"]], 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", 
      RowBox[{
       RowBox[{"a", " ", "b"}], "-", "1"}]], 
     RowBox[{"Log", "[", "x", "]"}]}], 
    RowBox[{
     SuperscriptBox["x", 
      RowBox[{"2", "a", " ", "b"}]], "-", "1"}]], 
   RowBox[{"Dt", "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5270106108343906`*^9, 3.527010622309538*^9}}],

Cell["This implies:", "Text",
 CellChangeTimes->{{3.527010761904496*^9, 3.527010763986704*^9}, 
   3.527010813297635*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Probability", "[", 
   RowBox[{
    RowBox[{"z", "\[LessEqual]", 
     SuperscriptBox["x", "b"]}], ",", 
    RowBox[{"z", "\[Distributed]", 
     RowBox[{"ExampleDistribution", "[", "a", "]"}]}]}], "]"}], " ", 
  "\[Equal]", " ", 
  RowBox[{"Probability", "[", 
   RowBox[{
    RowBox[{"z", "\[LessEqual]", "x"}], ",", 
    RowBox[{"z", "\[Distributed]", 
     RowBox[{"ExampleDistribution", "[", 
      RowBox[{"a", " ", "b"}], "]"}]}]}], "]"}]}]], "DisplayFormula",
 CellChangeTimes->{{3.527010768226128*^9, 3.527010810436349*^9}, {
  3.5270112290352044`*^9, 3.527011230176318*^9}},
 Background->RGBColor[0.87, 0.94, 1]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CDF", "Subsection",
 CellChangeTimes->{{3.5270108617934837`*^9, 3.5270108620455093`*^9}}],

Cell[TextData[{
 "Since ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["F", "a"], "[", "x", "]"}], "\[Equal]", 
    RowBox[{
     SubscriptBox["F", "1"], "[", 
     SuperscriptBox["x", "a"], "]"}]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.5270111919564967`*^9, 3.5270112188951902`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Probability", "[", 
  RowBox[{
   RowBox[{"z", "\[LessEqual]", "y"}], ",", 
   RowBox[{"z", "\[Distributed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ProbabilityDistribution", "[", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"4", 
           RowBox[{"a", "^", "2"}]}], 
          SuperscriptBox["\[Pi]", "2"]], 
         FractionBox[
          RowBox[{
           SuperscriptBox["x", 
            RowBox[{"a", "-", "1"}]], 
           RowBox[{"Log", "[", "x", "]"}]}], 
          RowBox[{
           SuperscriptBox["x", 
            RowBox[{"2", "a"}]], "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"a", ">", "0"}]}]}], "]"}], "/.", 
      RowBox[{"a", "\[Rule]", "1"}]}], ")"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"0", "<", "y", "<", "1"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5270108659568996`*^9, 3.5270108902233267`*^9}, {
  3.5270109519354973`*^9, 3.5270109606473684`*^9}, {3.527010993786682*^9, 
  3.527011166593961*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[Pi]", "2"], "-", 
   RowBox[{"6", " ", 
    RowBox[{"Log", "[", "y", "]"}], " ", 
    RowBox[{"Log", "[", 
     RowBox[{"1", "+", "y"}], "]"}]}], "-", 
   RowBox[{"6", " ", 
    RowBox[{"PolyLog", "[", 
     RowBox[{"2", ",", 
      RowBox[{"1", "-", "y"}]}], "]"}]}], "-", 
   RowBox[{"6", " ", 
    RowBox[{"PolyLog", "[", 
     RowBox[{"2", ",", 
      RowBox[{"-", "y"}]}], "]"}]}]}], 
  RowBox[{"3", " ", 
   SuperscriptBox["\[Pi]", "2"]}]]], "Output",
 CellChangeTimes->{
  3.5270108850858126`*^9, {3.527010961513455*^9, 3.527011093757678*^9}, {
   3.5270111621805196`*^9, 3.5270111674420457`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    FractionBox["2", 
     SuperscriptBox["\[Pi]", "2"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"PolyLog", "[", 
       RowBox[{"2", ",", "y"}], "]"}], "-", 
      RowBox[{"PolyLog", "[", 
       RowBox[{"2", ",", 
        RowBox[{"-", "y"}]}], "]"}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"ArcTanh", "[", "y", "]"}], " ", 
       RowBox[{"Log", "[", "y", "]"}]}]}], ")"}]}], "\[Equal]", "%"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5270111689721985`*^9, 3.527011177475049*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.527011178275129*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Moments", "Subsection",
 CellChangeTimes->{{3.527011445266825*^9, 3.527011446164915*^9}}],

Cell["\<\
Using reciprocation, it is enough to evaluate over unit interval:\
\>", "Text",
 CellChangeTimes->{{3.5270116576260595`*^9, 3.5270116871930156`*^9}, 
   3.527011723401636*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"4", 
      RowBox[{"a", "^", "2"}]}], 
     SuperscriptBox["\[Pi]", "2"]], 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", 
       RowBox[{"a", "-", "1"}]], 
      RowBox[{"Log", "[", "x", "]"}]}], 
     RowBox[{
      SuperscriptBox["x", 
       RowBox[{"2", "a"}]], "-", "1"}]], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "k"], "+", 
      SuperscriptBox["x", 
       RowBox[{"-", "k"}]]}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{
     RowBox[{"a", ">", "0"}], "&&", 
     RowBox[{"k", "\[GreaterEqual]", "0"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5270114532706256`*^9, 3.5270114551928177`*^9}, {
  3.5270115747237697`*^9, 3.527011590736371*^9}, {3.527011689718268*^9, 
  3.5270116978050766`*^9}, {3.5270694300657644`*^9, 3.527069432543906*^9}, {
  3.5270695426782055`*^9, 3.5270695478705025`*^9}, {3.52706961863455*^9, 
  3.5270696188565626`*^9}}],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Sec", "[", 
     FractionBox[
      RowBox[{"k", " ", "\[Pi]"}], 
      RowBox[{"2", " ", "a"}]], "]"}], "2"], ",", 
   RowBox[{"a", ">", "k"}]}], "]"}]], "Output",
 CellChangeTimes->{{3.5270115912644234`*^9, 3.5270116026935663`*^9}, 
   3.5270117990481997`*^9, 3.5270694430925093`*^9, 3.527069554698893*^9, 
   3.527069625851963*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Section",
 CellChangeTimes->{{3.526658810058318*^9, 3.526658814964809*^9}}],

Cell[CellGroupData[{

Cell["Clear definitions", "Subsection",
 CellChangeTimes->{{3.5266590190922194`*^9, 3.526659022906601*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "ExampleDistribution", "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5266590235206623`*^9, 3.5266590284871593`*^9}, 
   3.526659080134323*^9, {3.526659158196129*^9, 3.5266591608503942`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Predicates", "Subsection",
 CellChangeTimes->{{3.526658823415654*^9, 3.5266588252908416`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", "\[IndentingNewLine]", 
  RowBox[{"DistributionParameterAssumptions", "[", 
   RowBox[{"ExampleDistribution", "[", "a_", "]"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"a", "\[Element]", "Reals"}], "\[And]", 
   RowBox[{"a", ">", "0"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5266588305483675`*^9, 3.5266588866919813`*^9}, {
  3.5266590810844183`*^9, 3.5266590820015097`*^9}, {3.526659165480857*^9, 
  3.5266591669420033`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", "\[IndentingNewLine]", 
  RowBox[{"DistributionParameterQ", "[", 
   RowBox[{"di", ":", 
    RowBox[{"ExampleDistribution", "[", "a_", "]"}]}], "]"}], ":=", 
  RowBox[{"Or", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"!", 
     RowBox[{"NumericQ", "[", "a", "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Positive", "[", "a", "]"}], "===", "True"}], ")"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Message", "[", 
     RowBox[{
      RowBox[{"ExampleDistribution", "::", "posprm"}], ",", "a", ",", "1", 
      ",", "di"}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5266588305483675`*^9, 3.5266589222345347`*^9}, {
  3.5266589758428955`*^9, 3.526659009952306*^9}, {3.5266590830636163`*^9, 
  3.526659098094119*^9}, {3.5266591683481436`*^9, 3.5266591708703957`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", "\[IndentingNewLine]", 
  RowBox[{"Statistics`Library`DistributionNParameterQ", "[", 
   RowBox[{"di", ":", 
    RowBox[{"ExampleDistribution", "[", "a_", "]"}]}], "]"}], ":=", 
  RowBox[{"Or", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Positive", "[", "a", "]"}], "===", "True"}], ")"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Message", "[", 
     RowBox[{
      RowBox[{"ExampleDistribution", "::", "posprm"}], ",", "a", ",", "1", 
      ",", "di"}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5266588305483675`*^9, 3.5266589222345347`*^9}, {
  3.5266589758428955`*^9, 3.526659009952306*^9}, {3.5266590830636163`*^9, 
  3.5266591232396336`*^9}, {3.5266591726615753`*^9, 3.526659175144823*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Distribution functions", "Subsection",
 CellChangeTimes->{{3.526659141622472*^9, 3.5266591444707565`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"DistributionDomain", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
    "DistributionParameterQ"}], "]"}], ":=", 
  RowBox[{"Interval", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", "Infinity"}], "}"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.52666656248055*^9, 3.5266665757015495`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"PDF", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
     "DistributionParameterQ"}], ",", "z_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Function", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Piecewise", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"2", "a"}], 
           RowBox[{"Pi", "^", "2"}]], ",", 
          RowBox[{"x", "\[Equal]", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"4", 
             RowBox[{"a", "^", "2"}]}], 
            SuperscriptBox["\[Pi]", "2"]], 
           FractionBox[
            RowBox[{
             SuperscriptBox["x", 
              RowBox[{"a", "-", "1"}]], 
             RowBox[{"Log", "[", "x", "]"}]}], 
            RowBox[{
             SuperscriptBox["x", 
              RowBox[{"2", "a"}]], "-", "1"}]]}], ",", 
          RowBox[{"x", ">", "0"}]}], "}"}]}], "}"}], "]"}], ",", "Listable"}],
     "]"}], "[", "z", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5266591474720564`*^9, 3.5266591478120904`*^9}, {
  3.52665918001231*^9, 3.5266592664359517`*^9}, {3.52665939673298*^9, 
  3.5266593980761147`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"CDF", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
     "DistributionParameterQ"}], ",", "z_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Function", "[", 
    RowBox[{"x", ",", "\[IndentingNewLine]", 
     RowBox[{"Piecewise", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "2"], ",", 
          RowBox[{"x", "\[Equal]", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox["2", 
            SuperscriptBox["Pi", "2"]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], 
              RowBox[{"Log", "[", 
               RowBox[{"x", "^", "a"}], "]"}], " ", 
              RowBox[{"ArcTanh", "[", 
               RowBox[{"x", "^", "a"}], "]"}]}], "-", 
             RowBox[{"PolyLog", "[", 
              RowBox[{"2", ",", 
               RowBox[{"-", 
                RowBox[{"x", "^", "a"}]}]}], "]"}], "+", 
             RowBox[{"PolyLog", "[", 
              RowBox[{"2", ",", 
               RowBox[{"x", "^", "a"}]}], "]"}]}], ")"}]}], ",", 
          RowBox[{"1", ">", "x", ">", "0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{
            FractionBox["2", 
             SuperscriptBox["Pi", "2"]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", 
               RowBox[{"Log", "[", 
                RowBox[{"x", "^", "a"}], "]"}], " ", 
               RowBox[{"ArcTanh", "[", 
                RowBox[{"1", "/", 
                 RowBox[{"x", "^", "a"}]}], "]"}]}], "-", 
              RowBox[{"PolyLog", "[", 
               RowBox[{"2", ",", 
                RowBox[{
                 RowBox[{"-", "1"}], "/", 
                 RowBox[{"x", "^", "a"}]}]}], "]"}], "+", 
              RowBox[{"PolyLog", "[", 
               RowBox[{"2", ",", 
                RowBox[{"1", "/", 
                 RowBox[{"x", "^", "a"}]}]}], "]"}]}], ")"}]}]}], ",", 
          RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}], ",", "Listable"}],
     "]"}], "[", "z", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5266591474720564`*^9, 3.5266591478120904`*^9}, {
   3.52665918001231*^9, 3.5266594359509015`*^9}, {3.5266594705463605`*^9, 
   3.5266594734236484`*^9}, {3.52665957415172*^9, 3.526659648406145*^9}, 
   3.526659715953899*^9, {3.5270113443597355`*^9, 3.527011380277327*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"SurvivalFunction", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
     "DistributionParameterQ"}], ",", "z_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Function", "[", 
    RowBox[{"x", ",", "\[IndentingNewLine]", 
     RowBox[{"Piecewise", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           FractionBox["1", "2"], ",", 
           RowBox[{"x", "\[Equal]", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "-", 
            RowBox[{
             FractionBox["2", 
              SuperscriptBox["Pi", "2"]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], 
                RowBox[{"Log", "[", 
                 RowBox[{"x", "^", "a"}], "]"}], " ", 
                RowBox[{"ArcTanh", "[", 
                 RowBox[{"x", "^", "a"}], "]"}]}], "-", 
               RowBox[{"PolyLog", "[", 
                RowBox[{"2", ",", 
                 RowBox[{"-", 
                  RowBox[{"x", "^", "a"}]}]}], "]"}], "+", 
               RowBox[{"PolyLog", "[", 
                RowBox[{"2", ",", 
                 RowBox[{"x", "^", "a"}]}], "]"}]}], ")"}]}]}], ",", 
           RowBox[{"1", ">", "x", ">", "0"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["2", 
             SuperscriptBox["Pi", "2"]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", 
               RowBox[{"Log", "[", 
                RowBox[{"x", "^", "a"}], "]"}], " ", 
               RowBox[{"ArcTanh", "[", 
                RowBox[{"1", "/", 
                 RowBox[{"x", "^", "a"}]}], "]"}]}], "-", 
              RowBox[{"PolyLog", "[", 
               RowBox[{"2", ",", 
                RowBox[{
                 RowBox[{"-", "1"}], "/", 
                 RowBox[{"x", "^", "a"}]}]}], "]"}], "+", 
              RowBox[{"PolyLog", "[", 
               RowBox[{"2", ",", 
                RowBox[{"1", "/", 
                 RowBox[{"x", "^", "a"}]}]}], "]"}]}], ")"}]}], ",", 
           RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
     "Listable"}], "]"}], "[", "z", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5266591474720564`*^9, 3.5266591478120904`*^9}, {
  3.52665918001231*^9, 3.5266594359509015`*^9}, {3.5266594705463605`*^9, 
  3.5266594896902747`*^9}, {3.5266595236236677`*^9, 3.5266595287981853`*^9}, {
  3.5266597239687004`*^9, 3.526659733478651*^9}, {3.527011389698269*^9, 
  3.527011395758875*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"HazardFunction", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
     "DistributionParameterQ"}], ",", "z_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Function", "[", 
    RowBox[{"x", ",", "\[IndentingNewLine]", 
     RowBox[{"Piecewise", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"4", "a"}], 
           RowBox[{"Pi", "^", "2"}]], ",", 
          RowBox[{"x", "\[Equal]", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"4", 
             RowBox[{"a", "^", "2"}]}], 
            SuperscriptBox["\[Pi]", "2"]], 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["x", 
               RowBox[{"a", "-", "1"}]], 
              RowBox[{"Log", "[", "x", "]"}]}], 
             RowBox[{
              SuperscriptBox["x", 
               RowBox[{"2", "a"}]], "-", "1"}]], "/", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{
               FractionBox["2", 
                SuperscriptBox["Pi", "2"]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], 
                  RowBox[{"Log", "[", 
                   RowBox[{"x", "^", "a"}], "]"}], " ", 
                  RowBox[{"ArcTanh", "[", 
                   RowBox[{"x", "^", "a"}], "]"}]}], "-", 
                 RowBox[{"PolyLog", "[", 
                  RowBox[{"2", ",", 
                   RowBox[{"-", 
                    RowBox[{"x", "^", "a"}]}]}], "]"}], "+", 
                 RowBox[{"PolyLog", "[", 
                  RowBox[{"2", ",", 
                   RowBox[{"x", "^", "a"}]}], "]"}]}], ")"}]}]}], ")"}]}]}], 
          ",", 
          RowBox[{"1", ">", "x", ">", "0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", 
           RowBox[{"a", "^", "2"}], 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["x", 
               RowBox[{"a", "-", "1"}]], 
              RowBox[{"Log", "[", "x", "]"}]}], 
             RowBox[{
              SuperscriptBox["x", 
               RowBox[{"2", "a"}]], "-", "1"}]], " ", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", 
               RowBox[{"Log", "[", 
                RowBox[{"x", "^", "a"}], "]"}], " ", 
               RowBox[{"ArcTanh", "[", 
                RowBox[{"1", "/", 
                 RowBox[{"x", "^", "a"}]}], "]"}]}], "-", 
              RowBox[{"PolyLog", "[", 
               RowBox[{"2", ",", 
                RowBox[{
                 RowBox[{"-", "1"}], "/", 
                 RowBox[{"x", "^", "a"}]}]}], "]"}], "+", 
              RowBox[{"PolyLog", "[", 
               RowBox[{"2", ",", 
                RowBox[{"1", "/", 
                 RowBox[{"x", "^", "a"}]}]}], "]"}]}], ")"}]}]}], ",", 
          RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}], ",", "Listable"}],
     "]"}], "[", "z", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5266591474720564`*^9, 3.5266591478120904`*^9}, {
  3.52665918001231*^9, 3.5266594359509015`*^9}, {3.5266594705463605`*^9, 
  3.5266594896902747`*^9}, {3.5266595236236677`*^9, 3.5266595287981853`*^9}, {
  3.5266597239687004`*^9, 3.5266598016904716`*^9}, {3.5267420407305107`*^9, 
  3.5267420430087385`*^9}, {3.5270114119634953`*^9, 3.527011419856284*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Moments", "Subsection",
 CellChangeTimes->{{3.5266599211404157`*^9, 3.526659922006502*^9}}],

Cell[CellGroupData[{

Cell["Deriving", "Subsubsection",
 CellChangeTimes->{{3.526661934685568*^9, 3.5266619360265675`*^9}}],

Cell[TextData[{
 "Since the distribution has Paretian tails, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], "\[Tilde]", 
    FractionBox[
     RowBox[{"Log", "[", "x", "]"}], 
     SuperscriptBox["x", 
      RowBox[{"a", "+", "1"}]]]}], TraditionalForm]]],
 ",  moment existance conditions will be the same."
}], "Text",
 CellChangeTimes->{{3.5266608480320954`*^9, 3.5266608998752794`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Moment", "[", 
  RowBox[{
   RowBox[{"ParetoDistribution", "[", 
    RowBox[{"k", ",", "a"}], "]"}], ",", "k"}], "]"}]], "Input",
 CellChangeTimes->{{3.5266609023605275`*^9, 3.526660916626954*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        FractionBox[
         RowBox[{"a", " ", 
          SuperscriptBox["k", "k"]}], 
         RowBox[{"a", "-", "k"}]], 
        RowBox[{"k", "<", "a"}]},
       {"\[Infinity]", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{{3.526660911632455*^9, 3.526660916812973*^9}, 
   3.5266658169315295`*^9, 3.5267356343137302`*^9, 3.5267420528467226`*^9}]
}, Open  ]],

Cell["Making those assumptions:", "Text",
 CellChangeTimes->{{3.5266609252038116`*^9, 3.526660928896181*^9}, 
   3.526661044277718*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"4", 
      RowBox[{"a", "^", "2"}]}], 
     SuperscriptBox["\[Pi]", "2"]], 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", 
       RowBox[{"a", "-", "1"}]], 
      RowBox[{"Log", "[", "x", "]"}]}], 
     RowBox[{
      SuperscriptBox["x", 
       RowBox[{"2", "a"}]], "-", "1"}]], 
    RowBox[{"x", "^", "k"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"a", ">", "k", ">", "0"}]}]}], "]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.526660094054705*^9, 3.526660119276227*^9}}],

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"Sec", "[", 
   FractionBox[
    RowBox[{"k", " ", "\[Pi]"}], 
    RowBox[{"2", " ", "a"}]], "]"}], "2"]], "Output",
 CellChangeTimes->{3.526660103550655*^9, 3.5266601743497343`*^9, 
  3.526665847783408*^9, 3.526665928721217*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "=", "7"}], ",", 
     RowBox[{"k", "=", "4"}]}], "}"}], ",", 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"4", 
         RowBox[{"a", "^", "2"}]}], 
        SuperscriptBox["\[Pi]", "2"]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["x", 
          RowBox[{"a", "-", "1"}]], 
         RowBox[{"Log", "[", "x", "]"}]}], 
        RowBox[{
         SuperscriptBox["x", 
          RowBox[{"2", "a"}]], "-", "1"}]], 
       RowBox[{"x", "^", "k"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
      RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], "]"}], "-", 
    SuperscriptBox[
     RowBox[{"Sec", "[", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]"}], "a"], "]"}], "2"]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5266603960679035`*^9, 3.526660423107607*^9}}],

Cell[BoxData["0``49.58965870862768"], "Output",
 CellChangeTimes->{{3.5266604161119075`*^9, 3.526660423563653*^9}, 
   3.5267356346127605`*^9, 3.526742053071745*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["General moments", "Subsubsection",
 CellChangeTimes->{{3.5266606941367073`*^9, 3.526660700733367*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Moment", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
     "DistributionParameterQ"}], ",", "k_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Function", "[", 
    RowBox[{"r", ",", "\[IndentingNewLine]", 
     RowBox[{"Piecewise", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sec", "[", 
           FractionBox[
            RowBox[{"r", " ", "\[Pi]"}], 
            RowBox[{"2", " ", "a"}]], "]"}], ",", 
          RowBox[{"a", ">", "r"}]}], "}"}], "}"}], ",", "Infinity"}], "]"}], 
     ",", "Listable"}], "]"}], "[", "k", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526660300058304*^9, 3.526660366049902*^9}, {
  3.526660537375033*^9, 3.526660537395035*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"CentralMoment", "[", 
   RowBox[{
    RowBox[{"di", ":", 
     RowBox[{
      RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
      "DistributionParameterQ"}]}], ",", 
    RowBox[{"k_Integer", "?", "NonNegative"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Statistics`Library`UnivariateMomentsConvert", "[", 
   RowBox[{"di", ",", "k", ",", 
    RowBox[{"Moment", "\[Rule]", "CentralMoment"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526660723675661*^9, 3.5266607647127647`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"FactorialMoment", "[", 
   RowBox[{
    RowBox[{"di", ":", 
     RowBox[{
      RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
      "DistributionParameterQ"}]}], ",", 
    RowBox[{"k_Integer", "?", "NonNegative"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Statistics`Library`UnivariateMomentsConvert", "[", 
   RowBox[{"di", ",", "k", ",", 
    RowBox[{"Moment", "\[Rule]", "FactorialMoment"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526660723675661*^9, 3.526660776720965*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Cumulant", "[", 
   RowBox[{
    RowBox[{"di", ":", 
     RowBox[{
      RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
      "DistributionParameterQ"}]}], ",", 
    RowBox[{"k_Integer", "?", "NonNegative"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Statistics`Library`UnivariateMomentsConvert", "[", 
   RowBox[{"di", ",", "k", ",", 
    RowBox[{"Moment", "\[Rule]", "Cumulant"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526660723675661*^9, 3.5266607831856117`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Named moments", "Subsubsection",
 CellChangeTimes->{{3.526660703851679*^9, 3.5266607108613796`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Mean", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
    "DistributionParameterQ"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Sec", "[", 
        FractionBox["\[Pi]", 
         RowBox[{"2", " ", "a"}]], "]"}], ",", 
       RowBox[{"a", ">", "1"}]}], "}"}], "}"}], ",", "Infinity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526660432457542*^9, 3.5266604527195683`*^9}, {
  3.526660540122308*^9, 3.526660540127308*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Variance", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
    "DistributionParameterQ"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Sec", "[", 
         FractionBox["\[Pi]", "a"], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Tan", "[", 
          FractionBox["\[Pi]", 
           RowBox[{"2", " ", "a"}]], "]"}], "2"]}], ",", 
       RowBox[{"a", ">", "2"}]}], "}"}], "}"}], ",", "Infinity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526660432457542*^9, 3.526660482210517*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"StandardDeviation", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
    "DistributionParameterQ"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Sec", "[", 
          FractionBox["\[Pi]", "a"], "]"}], 
         RowBox[{"1", "/", "2"}]], " ", 
        RowBox[{"Tan", "[", 
         FractionBox["\[Pi]", 
          RowBox[{"2", " ", "a"}]], "]"}]}], ",", 
       RowBox[{"a", ">", "2"}]}], "}"}], "}"}], ",", "Infinity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526660432457542*^9, 3.526660482210517*^9}, {
  3.5266608240296955`*^9, 3.5266608335836506`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Skewness", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
    "DistributionParameterQ"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"6", " ", 
         SqrtBox[
          RowBox[{"Cos", "[", 
           FractionBox["\[Pi]", "a"], "]"}]], " ", 
         RowBox[{"Sin", "[", 
          FractionBox["\[Pi]", 
           RowBox[{"2", " ", "a"}]], "]"}]}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", 
           FractionBox["\[Pi]", "a"], "]"}]}]}]], ",", 
       RowBox[{"a", ">", "3"}]}], "}"}], "}"}], ",", "Infinity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526660432457542*^9, 3.526660482210517*^9}, {
   3.526660547456041*^9, 3.526660550402335*^9}, 3.5266606189591904`*^9}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Kurtosis", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
    "DistributionParameterQ"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "7"}], "+", 
          FractionBox["24", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", 
              FractionBox["\[Pi]", "a"], "]"}]}]}]], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"17", "+", 
             RowBox[{"24", " ", 
              RowBox[{"Cos", "[", 
               FractionBox["\[Pi]", "a"], "]"}]}]}], ")"}], " ", 
           RowBox[{"Sec", "[", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]"}], "a"], "]"}]}]}], ")"}]}], ",", 
       RowBox[{"a", ">", "4"}]}], "}"}], "}"}], ",", "Infinity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526660432457542*^9, 3.526660482210517*^9}, {
   3.526660547456041*^9, 3.526660550402335*^9}, 3.5266606189591904`*^9, {
   3.5266606696152554`*^9, 3.5266606783981333`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generating functions", "Subsection",
 CellChangeTimes->{{3.526661958131568*^9, 3.526661967067568*^9}}],

Cell["\<\
Since moments are only finite up to a fixed order, neither of moment \
generating functions exist, so we do not define them.\
\>", "Text",
 CellChangeTimes->{{3.5268317021538477`*^9, 3.526831729947627*^9}}],

Cell[TextData[{
 "Characteristic function is only expressible in terms of Fox H function for \
generic parameter ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.5268317346941013`*^9, 3.526831765426174*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Characteristic function for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "\[Equal]", "1"}], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.5267454262850604`*^9, 3.5267454349350605`*^9}}],

Cell["\<\
If the distribution density is symmetrically extended to the real line, then \
characteristic function is\
\>", "Text",
 CellChangeTimes->{{3.5273494939081526`*^9, 3.5273495217349353`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expectation", "[", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", "x"}], "]"}], ",", 
   RowBox[{"x", "\[Distributed]", 
    RowBox[{"ExampleDistribution", "[", "1", "]"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"t", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5267452794310603`*^9, 3.52674533553106*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"\[Pi]", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"CosIntegral", "[", "t", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", "t", "]"}], " ", 
    RowBox[{"SinIntegral", "[", "t", "]"}]}]}], "\[Pi]"]], "Output",
 CellChangeTimes->{{3.5267453131430607`*^9, 3.5267453473550606`*^9}, 
   3.526831858227453*^9}]
}, Open  ]],

Cell["For the distribution as is, it is more complicated:", "Text",
 CellChangeTimes->{{3.526831955809211*^9, 3.5268319678214116`*^9}, {
  3.5273495476515265`*^9, 3.5273495834071016`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"CharacteristicFunction", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "1", "]"}], ",", "t_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"CosIntegral", "[", "t", "]"}], " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Cos", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", "-", 
        RowBox[{"2", " ", 
         RowBox[{"SinIntegral", "[", "t", "]"}]}]}], ")"}]}]}], "\[Pi]"], "+", 
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", "  ", 
      RowBox[{"Sign", "[", "t", "]"}]}], 
     SuperscriptBox["\[Pi]", 
      RowBox[{"3", "/", "2"}]]], 
    RowBox[{"MeijerG", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "2"], ",", 
          FractionBox["1", "2"]}], "}"}], ",", 
        RowBox[{"{", "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "2"], ",", 
          FractionBox["1", "2"], ",", 
          FractionBox["1", "2"]}], "}"}], ",", 
        RowBox[{"{", "0", "}"}]}], "}"}], ",", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["t", "2"], ")"}], "2"]}], "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5268320012737565`*^9, 3.52683204690932*^9}, {
  3.527349730763082*^9, 3.527349733711082*^9}}],

Cell["Plot real and imaginary parts of the characteristic function", "Text",
 CellChangeTimes->{{3.526831975378167*^9, 3.526831993746004*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"CosIntegral", "[", "t", "]"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", "-", 
          RowBox[{"2", " ", 
           RowBox[{"SinIntegral", "[", "t", "]"}]}]}], ")"}]}]}], "\[Pi]"], 
     ",", 
     RowBox[{
      RowBox[{"MeijerG", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "2"], ",", 
            FractionBox["1", "2"]}], "}"}], ",", 
          RowBox[{"{", "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "2"], ",", 
            FractionBox["1", "2"], ",", 
            FractionBox["1", "2"]}], "}"}], ",", 
          RowBox[{"{", "0", "}"}]}], "}"}], ",", 
        FractionBox["t", "2"], ",", 
        FractionBox["1", "2"]}], "]"}], "/", 
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"3", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5267494512655373`*^9, 3.52674948949636*^9}, 
   3.526750518374237*^9, {3.527349747109082*^9, 3.5273497546030817`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlHk8FHgDxkflSoecEWIsUahWCdt6fkLJOjqsWio6t3NVco8jmaksyqvD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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4FfsfB3BlKfHLEkJUTolQUqFceY+KKCIkucnNbVGKpKTI1jmUSgtu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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.526749461255536*^9, 3.5267494721056213`*^9}, 
   3.5267495131587257`*^9, 3.5267505294043407`*^9, 3.527349764693082*^9}]
}, Open  ]],

Cell[TextData[{
 "It is easy to see that no moments exists for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "\[Equal]", "1"}], TraditionalForm]]],
 ", because"
}], "Text",
 CellChangeTimes->{{3.527349661868082*^9, 3.527349681479082*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "I"}], " ", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"Refine", "[", 
        RowBox[{
         RowBox[{"CharacteristicFunction", "[", 
          RowBox[{
           RowBox[{"ExampleDistribution", "[", "1", "]"}], ",", "t"}], "]"}], 
         ",", 
         RowBox[{"t", ">", "0"}]}], "]"}], ",", "t"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"t", ">", "0"}]}]}], "]"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.527349783071082*^9, 3.5273498547090816`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"12", " ", 
      SuperscriptBox["EulerGamma", "2"]}], "-", 
     RowBox[{"12", " ", "\[ImaginaryI]", " ", "EulerGamma", " ", "\[Pi]"}], 
     "+", 
     SuperscriptBox["\[Pi]", "2"], "+", 
     RowBox[{"12", " ", 
      RowBox[{"Log", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "EulerGamma"}], "-", 
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "+", 
        RowBox[{"Log", "[", "t", "]"}]}], ")"}]}]}], 
    RowBox[{"6", " ", 
     SuperscriptBox["\[Pi]", "2"]}]], "+", 
   RowBox[{"\[ImaginaryI]", " ", "t"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "2"],
    SeriesData[$CellContext`t, 0, {}, 0, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(Rational[1, 6] Pi^(-2)) (
     12 EulerGamma^2 + (Complex[0, -12] EulerGamma) Pi + 
     Pi^2 + (12 Log[$CellContext`t]) (2 EulerGamma + Complex[0, -1] Pi + 
       Log[$CellContext`t])), 
    Complex[0, 1]}, 0, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.527349797982082*^9, 3.527349855328082*^9}, 
   3.527349924543082*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Expression for characteristic function in terms of Fox H", \
"Subsubsection",
 CellChangeTimes->{{3.5267454027270603`*^9, 3.5267454202440605`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     FractionBox["4", 
      SuperscriptBox["\[Pi]", "2"]], 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"Log", "[", "x", "]"}]}], 
      RowBox[{
       SuperscriptBox["x", "2"], "-", "1"}]], 
     SuperscriptBox["x", 
      RowBox[{"s", "-", "1"}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}], "\[Equal]", 
  RowBox[{"ConditionalExpression", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox["s", "2"], "]"}], "^", "2"}], 
     RowBox[{
      RowBox[{
       RowBox[{"Gamma", "[", 
        RowBox[{"1", "-", 
         FractionBox["s", "2"]}], "]"}], "^", "2"}], "/", 
      RowBox[{"Pi", "^", "2"}]}]}], ",", 
    RowBox[{"0", "<", 
     RowBox[{"Re", "[", "s", "]"}], "<", "2"}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5266621067145452`*^9, 3.5266621290217752`*^9}, {
   3.526662315745446*^9, 3.5266623612579966`*^9}, 3.526662407252596*^9}],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"Csc", "[", 
      FractionBox[
       RowBox[{"\[Pi]", " ", "s"}], "2"], "]"}], "2"], "\[Equal]", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"Gamma", "[", 
        RowBox[{"1", "-", 
         FractionBox["s", "2"]}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Gamma", "[", 
        FractionBox["s", "2"], "]"}], "2"]}], 
     SuperscriptBox["\[Pi]", "2"]]}], ",", 
   RowBox[{"0", "<", 
    RowBox[{"Re", "[", "s", "]"}], "<", "2"}]}], "]"}]], "Output",
 CellChangeTimes->{3.5266621227501483`*^9, 3.5266621890777807`*^9, 
  3.526662404931364*^9, 3.5266624357844486`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5266623305779295`*^9, 3.5266623718880596`*^9}}],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{"True", ",", 
   RowBox[{"0", "<", 
    RowBox[{"Re", "[", "s", "]"}], "<", "2"}]}], "]"}]], "Output",
 CellChangeTimes->{{3.526662333475219*^9, 3.5266623445043216`*^9}, 
   3.5266624387477455`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"t", " ", 
      SuperscriptBox["x", 
       RowBox[{"1", "/", "a"}]]}], "]"}], 
    SuperscriptBox["x", 
     RowBox[{"s", "-", "1"}]]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{
     RowBox[{"a", ">", "0"}], "&&", 
     RowBox[{"t", ">", "0"}]}]}]}], "]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.526662149805854*^9, 3.526662200792952*^9}, {
  3.5266622418950615`*^9, 3.5266622448943615`*^9}, {3.526662466337504*^9, 
  3.526662466966567*^9}, {3.526664882726118*^9, 3.5266649116820135`*^9}, {
  3.5266649646403093`*^9, 3.526664964942339*^9}}],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   RowBox[{"a", " ", 
    SuperscriptBox["t", 
     RowBox[{
      RowBox[{"-", "a"}], " ", "s"}]], " ", 
    RowBox[{"Cos", "[", 
     FractionBox[
      RowBox[{"a", " ", "\[Pi]", " ", "s"}], "2"], "]"}], " ", 
    RowBox[{"Gamma", "[", 
     RowBox[{"a", " ", "s"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"Re", "[", "s", "]"}]}], "<", "1"}], "&&", 
    RowBox[{
     RowBox[{"Re", "[", "s", "]"}], ">", "0"}]}]}], "]"}]], "Output",
 CellChangeTimes->{
  3.526662207462619*^9, 3.526662254206293*^9, 3.5266624752643967`*^9, {
   3.5266648875656023`*^9, 3.526664914686314*^9}, 3.526664967469592*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"t", " ", 
      SuperscriptBox["x", 
       RowBox[{"1", "/", "a"}]]}], "]"}], 
    SuperscriptBox["x", 
     RowBox[{"s", "-", "1"}]]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{
     RowBox[{"a", ">", "0"}], "&&", 
     RowBox[{"t", ">", "0"}]}]}]}], "]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.526662149805854*^9, 3.526662200792952*^9}, {
  3.5266622418950615`*^9, 3.5266622448943615`*^9}, {3.526662466337504*^9, 
  3.526662466966567*^9}, {3.526664882726118*^9, 3.5266649283026752`*^9}, {
  3.5266649700708523`*^9, 3.5266649702688723`*^9}}],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   RowBox[{"a", " ", 
    SuperscriptBox["t", 
     RowBox[{
      RowBox[{"-", "a"}], " ", "s"}]], " ", 
    RowBox[{"Gamma", "[", 
     RowBox[{"a", " ", "s"}], "]"}], " ", 
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"a", " ", "\[Pi]", " ", "s"}], "2"], "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"Re", "[", "s", "]"}]}], "<", "1"}], "&&", 
    RowBox[{
     RowBox[{"Re", "[", "s", "]"}], ">", "0"}]}]}], "]"}]], "Output",
 CellChangeTimes->{3.526664931289974*^9, 3.52666497314916*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"a", " ", "\[Pi]", " ", "s"}], "2"], "]"}], "\[Equal]", 
     FractionBox["Pi", 
      RowBox[{
       RowBox[{"Gamma", "[", 
        RowBox[{
         FractionBox["1", "2"], "-", 
         FractionBox[
          RowBox[{"a", " ", "s"}], "2"]}], "]"}], 
       RowBox[{"Gamma", "[", 
        RowBox[{
         FractionBox["1", "2"], "+", 
         FractionBox[
          RowBox[{"a", " ", "s"}], "2"]}], "]"}]}]]}], ",", 
    RowBox[{
     RowBox[{"Sin", "[", 
      FractionBox[
       RowBox[{"a", " ", "\[Pi]", " ", "s"}], "2"], "]"}], "\[Equal]", 
     FractionBox["Pi", 
      RowBox[{
       RowBox[{"Gamma", "[", 
        FractionBox[
         RowBox[{"a", " ", "s"}], "2"], "]"}], 
       RowBox[{"Gamma", "[", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"a", " ", "s"}], "2"]}], "]"}]}]]}]}], "}"}], "//", 
  "FullSimplify"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5266650240612507`*^9, 3.526665081303974*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.526665049015746*^9, 3.526665081938038*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"Gamma", "[", 
           RowBox[{"1", "-", 
            FractionBox["s", "2"]}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Gamma", "[", 
           FractionBox["s", "2"], "]"}], "2"]}], 
        SuperscriptBox["\[Pi]", "2"]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"a", " ", 
            SuperscriptBox["t", 
             RowBox[{
              RowBox[{"-", "a"}], " ", "s"}]], " ", 
            FractionBox["Pi", 
             RowBox[{
              RowBox[{"Gamma", "[", 
               RowBox[{
                FractionBox["1", "2"], "-", 
                FractionBox[
                 RowBox[{"a", " ", "s"}], "2"]}], "]"}], 
              RowBox[{"Gamma", "[", 
               RowBox[{
                FractionBox["1", "2"], "+", 
                FractionBox[
                 RowBox[{"a", " ", "s"}], "2"]}], "]"}]}]], " ", 
            RowBox[{"Gamma", "[", 
             RowBox[{"a", " ", "s"}], "]"}]}], ",", 
           RowBox[{"a", " ", 
            SuperscriptBox["t", 
             RowBox[{
              RowBox[{"-", "a"}], " ", "s"}]], " ", 
            RowBox[{"Gamma", "[", 
             RowBox[{"a", " ", "s"}], "]"}], " ", 
            FractionBox["Pi", 
             RowBox[{
              RowBox[{"Gamma", "[", 
               FractionBox[
                RowBox[{"a", " ", "s"}], "2"], "]"}], 
              RowBox[{"Gamma", "[", 
               RowBox[{"1", "-", 
                FractionBox[
                 RowBox[{"a", " ", "s"}], "2"]}], "]"}]}]]}]}], "}"}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{"1", "-", "s"}]}]}], ")"}]}], "//", "ExpandAll"}], ")"}], 
    FractionBox["1", "a"]}], "/.", 
   RowBox[{"s", "\[Rule]", 
    RowBox[{"1", "-", 
     RowBox[{"s", "/", "a"}]}]}]}], "//", "ExpandAll"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5266649933461795`*^9, 3.526665017535598*^9}, {
  3.5266650919780416`*^9, 3.5266651525650997`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["t", 
      RowBox[{"-", "s"}]], " ", 
     RowBox[{"Gamma", "[", "s", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"Gamma", "[", 
       RowBox[{
        FractionBox["1", "2"], "-", 
        FractionBox["s", 
         RowBox[{"2", " ", "a"}]]}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Gamma", "[", 
       RowBox[{
        FractionBox["1", "2"], "+", 
        FractionBox["s", 
         RowBox[{"2", " ", "a"}]]}], "]"}], "2"]}], 
    RowBox[{"\[Pi]", " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox["s", "2"]}], "]"}], " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox["s", "2"]}], "]"}]}]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["t", 
      RowBox[{"-", "s"}]], " ", 
     RowBox[{"Gamma", "[", "s", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"Gamma", "[", 
       RowBox[{
        FractionBox["1", "2"], "-", 
        FractionBox["s", 
         RowBox[{"2", " ", "a"}]]}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Gamma", "[", 
       RowBox[{
        FractionBox["1", "2"], "+", 
        FractionBox["s", 
         RowBox[{"2", " ", "a"}]]}], "]"}], "2"]}], 
    RowBox[{"\[Pi]", " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{"1", "-", 
       FractionBox["s", "2"]}], "]"}], " ", 
     RowBox[{"Gamma", "[", 
      FractionBox["s", "2"], "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.5266650117690215`*^9, 3.5266650177586203`*^9}, 
   3.526665096848529*^9, {3.5266651359404373`*^9, 3.5266651532321663`*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CharacteristicFunction", "[", 
   RowBox[{
    RowBox[{"ExampleDistriubtion", "[", "a", "]"}], ",", "t"}], "]"}], 
  "\[Equal]", 
  RowBox[{
   RowBox[{
    FractionBox["1", "Pi"], 
    RowBox[{"FoxH", "[", " ", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "2"], ",", 
            FractionBox["1", 
             RowBox[{"2", "a"}]]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "2"], ",", 
            FractionBox["1", 
             RowBox[{"2", "a"}]]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           FractionBox["1", "2"], ",", 
           FractionBox["1", "2"]}], "}"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "2"], ",", 
            FractionBox["1", 
             RowBox[{"2", "a"}]]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "2"], ",", 
            FractionBox["1", 
             RowBox[{"2", "a"}]]}], "}"}]}], " ", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           FractionBox["1", "2"], ",", 
           FractionBox["1", "2"]}], "}"}], "}"}]}], "}"}], ",", "t"}], 
     "]"}]}], "+", 
   RowBox[{"I", " ", 
    RowBox[{"Sign", "[", "t", "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox["1", "Pi"], 
  RowBox[{"FoxH", "[", " ", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "2"], ",", 
          FractionBox["1", 
           RowBox[{"2", "a"}]]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "2"], ",", 
          FractionBox["1", 
           RowBox[{"2", "a"}]]}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox["1", "2"]}], "}"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "2"], ",", 
          FractionBox["1", 
           RowBox[{"2", "a"}]]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "2"], ",", 
          FractionBox["1", 
           RowBox[{"2", "a"}]]}], "}"}]}], " ", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox["1", "2"]}], "}"}], "}"}]}], "}"}], ",", "t"}], 
   "]"}]}]}], "DisplayFormula",
 CellChangeTimes->{{3.5266651680876517`*^9, 3.5266652568115234`*^9}, {
  3.5266653062914705`*^9, 3.5266653145292945`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Quantile and Median, InverseCDF, InverseSurvivalFunction", "Subsection",
 CellChangeTimes->{{3.526665346960537*^9, 3.5266653816500063`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Median", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
    "DistributionParameterQ"}], "]"}], ":=", "1"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5266655081296525`*^9, 3.52666552110295*^9}, 
   3.5266660516026363`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantileQ", "[", "x_", "]"}], ":=", 
  RowBox[{"Statistics`Library`QuantileQ", "[", "x", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5266654386427045`*^9, 3.5266654569925394`*^9}}],

Cell["\<\
Statistics`Library`nQuantileFindRoot[
\tcdf[x],
\tpdf[x],
\tq,
\t{x, x0, \"DomainLowerPoint\", \"DomainUpperPoint\" }
] 

Initial point x0 can be Automatic\
\>", "Program",
 CellChangeTimes->{{3.527994919508433*^9, 3.527995013317433*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Quantile", "|", "InverseCDF"}], ")"}], "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], ",", 
    RowBox[{"q_", "?", "QuantileQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "res", ",", "cdf", ",", "pdf", ",", 
      RowBox[{"x0", "=", "Automatic"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"cdf", "=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           FractionBox["1", "2"], ",", 
           RowBox[{"x", "\[Equal]", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["2", 
             SuperscriptBox["Pi", "2"]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Log", "[", 
                RowBox[{"x", "^", "a"}], "]"}], " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 RowBox[{"1", "-", 
                  RowBox[{"x", "^", "a"}]}], 
                 RowBox[{"1", "+", 
                  RowBox[{"x", "^", "a"}]}]], "]"}]}], "-", 
              RowBox[{"PolyLog", "[", 
               RowBox[{"2", ",", 
                RowBox[{"-", 
                 RowBox[{"x", "^", "a"}]}]}], "]"}], "+", 
              RowBox[{"PolyLog", "[", 
               RowBox[{"2", ",", 
                RowBox[{"x", "^", "a"}]}], "]"}]}], ")"}]}], ",", 
           RowBox[{"1", ">", "x", ">", "0"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "-", 
            RowBox[{
             FractionBox["2", 
              SuperscriptBox["Pi", "2"]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"Log", "[", 
                  RowBox[{"x", "^", "a"}], "]"}]}], " ", 
                RowBox[{"Log", "[", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"x", "^", "a"}], "-", "1"}], 
                  RowBox[{"1", "+", 
                   RowBox[{"x", "^", "a"}]}]], "]"}]}], "-", 
               RowBox[{"PolyLog", "[", 
                RowBox[{"2", ",", 
                 RowBox[{
                  RowBox[{"-", "1"}], "/", 
                  RowBox[{"x", "^", "a"}]}]}], "]"}], "+", 
               RowBox[{"PolyLog", "[", 
                RowBox[{"2", ",", 
                 RowBox[{"1", "/", 
                  RowBox[{"x", "^", "a"}]}]}], "]"}]}], ")"}]}]}], ",", 
           RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pdf", "=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           FractionBox[
            RowBox[{"2", "a"}], 
            RowBox[{"Pi", "^", "2"}]], ",", 
           RowBox[{"x", "\[Equal]", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"4", 
              RowBox[{"a", "^", "2"}]}], 
             SuperscriptBox["\[Pi]", "2"]], 
            FractionBox[
             RowBox[{
              SuperscriptBox["x", 
               RowBox[{"a", "-", "1"}]], 
              RowBox[{"Log", "[", "x", "]"}]}], 
             RowBox[{
              SuperscriptBox["x", 
               RowBox[{"2", "a"}]], "-", "1"}]]}], ",", 
           RowBox[{"x", ">", "0"}]}], "}"}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"NumericQ", "[", "q", "]"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"0", "<", "q", "<", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{"x0", "=", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"q", ">", 
            RowBox[{"1", "/", "2"}]}], ",", 
           RowBox[{"x0", "=", "2"}]}], "]"}]}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"res", "=", 
      RowBox[{"Statistics`Library`nQuantileFindRoot", "[", 
       RowBox[{"cdf", ",", "pdf", ",", "q", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "x0", ",", "0", ",", "Infinity"}], "}"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"res", "/;", 
      RowBox[{"res", "=!=", "$Failed"}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526665359576799*^9, 3.5266654165464954`*^9}, {
   3.52666546320016*^9, 3.5266654929651365`*^9}, {3.5266655617910185`*^9, 
   3.526665764890326*^9}, 3.526666056497657*^9, 3.5266663503315496`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExampleDistribution", "/:", 
   RowBox[{"InverseSurvivalFunction", "[", 
    RowBox[{
     RowBox[{"ExampleDistribution", "[", "a_", "]"}], ",", 
     RowBox[{"q_", "?", "QuantileQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "res", ",", "sf", ",", "pdf", ",", 
       RowBox[{"x0", "=", "Automatic"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sf", "=", 
       RowBox[{"Piecewise", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{"4", "a"}], 
             RowBox[{"Pi", "^", "2"}]], ",", 
            RowBox[{"x", "\[Equal]", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             FractionBox[
              RowBox[{"4", 
               RowBox[{"a", "^", "2"}]}], 
              SuperscriptBox["\[Pi]", "2"]], 
             RowBox[{
              FractionBox[
               RowBox[{
                SuperscriptBox["x", 
                 RowBox[{"a", "-", "1"}]], 
                RowBox[{"Log", "[", "x", "]"}]}], 
               RowBox[{
                SuperscriptBox["x", 
                 RowBox[{"2", "a"}]], "-", "1"}]], "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{
                 FractionBox["2", 
                  SuperscriptBox["Pi", "2"]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"x", "^", "a"}], "]"}], " ", 
                    RowBox[{"Log", "[", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    RowBox[{"x", "^", "a"}]}], 
                    RowBox[{"1", "+", 
                    RowBox[{"x", "^", "a"}]}]], "]"}]}], "-", 
                   RowBox[{"PolyLog", "[", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", 
                    RowBox[{"x", "^", "a"}]}]}], "]"}], "+", 
                   RowBox[{"PolyLog", "[", 
                    RowBox[{"2", ",", 
                    RowBox[{"x", "^", "a"}]}], "]"}]}], ")"}]}]}], ")"}]}]}], 
            ",", 
            RowBox[{"1", ">", "x", ">", "0"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", 
             RowBox[{"a", "^", "2"}], 
             RowBox[{
              FractionBox[
               RowBox[{
                SuperscriptBox["x", 
                 RowBox[{"a", "-", "1"}]], 
                RowBox[{"Log", "[", "x", "]"}]}], 
               RowBox[{
                SuperscriptBox["x", 
                 RowBox[{"2", "a"}]], "-", "1"}]], " ", "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"Log", "[", 
                   RowBox[{"x", "^", "a"}], "]"}]}], " ", 
                 RowBox[{"Log", "[", 
                  FractionBox[
                   RowBox[{
                    RowBox[{"x", "^", "a"}], "-", "1"}], 
                   RowBox[{"1", "+", 
                    RowBox[{"x", "^", "a"}]}]], "]"}]}], "-", 
                RowBox[{"PolyLog", "[", 
                 RowBox[{"2", ",", 
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{"x", "^", "a"}]}]}], "]"}], "+", 
                RowBox[{"PolyLog", "[", 
                 RowBox[{"2", ",", 
                  RowBox[{"1", "/", 
                   RowBox[{"x", "^", "a"}]}]}], "]"}]}], ")"}]}]}], ",", 
            RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"pdf", "=", 
       RowBox[{"Piecewise", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{"2", "a"}], 
             RowBox[{"Pi", "^", "2"}]], ",", 
            RowBox[{"x", "\[Equal]", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             FractionBox[
              RowBox[{"4", 
               RowBox[{"a", "^", "2"}]}], 
              SuperscriptBox["\[Pi]", "2"]], 
             FractionBox[
              RowBox[{
               SuperscriptBox["x", 
                RowBox[{"a", "-", "1"}]], 
               RowBox[{"Log", "[", "x", "]"}]}], 
              RowBox[{
               SuperscriptBox["x", 
                RowBox[{"2", "a"}]], "-", "1"}]]}], ",", 
            RowBox[{"x", ">", "0"}]}], "}"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"NumericQ", "[", "q", "]"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"0", "<", "q", "<", 
           RowBox[{"1", "/", "2"}]}], ",", 
          RowBox[{"x0", "=", "2"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"q", ">", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"x0", "=", 
             RowBox[{"1", "/", "2"}]}]}], "]"}]}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"res", "=", 
       RowBox[{"Statistics`Library`nInverseSFFindRoot", "[", 
        RowBox[{"sf", ",", "pdf", ",", "q", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "x0", ",", "0", ",", "Infinity"}], "}"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"res", "/;", 
       RowBox[{"res", "=!=", "$Failed"}]}]}]}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526665359576799*^9, 3.5266654165464954`*^9}, {
   3.52666546320016*^9, 3.5266654929651365`*^9}, {3.5266655617910185`*^9, 
   3.526665801682005*^9}, 3.5266660591841197`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Random Number Generation", "Subsection",
 CellChangeTimes->{{3.5266676713149776`*^9, 3.52666767613946*^9}}],

Cell[CellGroupData[{

Cell["Useful properties", "Subsubsection",
 CellChangeTimes->{{3.526741474454889*^9, 3.5267414801504583`*^9}, {
  3.5267423130607414`*^9, 3.5267423136848035`*^9}}],

Cell[TextData[{
 "There is a one-to-one mapping between ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "<", "x", "<", "1"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", ">", "1"}], TraditionalForm]]],
 " that preserves the distribution function:"
}], "Text",
 CellChangeTimes->{{3.5267427780096755`*^9, 3.5267428294236755`*^9}}],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"0", "<", "x", "<", "1"}], "\[And]", 
    RowBox[{"a", ">", "0"}]}], ",", 
   RowBox[{"FullSimplify", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Probability", "[", 
      RowBox[{
       RowBox[{"y", "<", "x"}], ",", 
       RowBox[{"y", "\[Distributed]", 
        RowBox[{"ExampleDistribution", "[", "a", "]"}]}]}], "]"}], "\[Equal]", 
     RowBox[{"Probability", "[", 
      RowBox[{
       RowBox[{"y", ">", 
        FractionBox["1", "x"]}], ",", 
       RowBox[{"y", "\[Distributed]", 
        RowBox[{"ExampleDistribution", "[", "a", "]"}]}]}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5267428541716757`*^9, 3.5267429243016753`*^9}}],

Cell["Regions are equiprobable:", "Text",
 CellChangeTimes->{{3.526742798165675*^9, 3.5267428001966753`*^9}, {
  3.5267429297136755`*^9, 3.5267429749206753`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Probability", "[", 
   RowBox[{
    RowBox[{"y", "<", "1"}], ",", 
    RowBox[{"y", "\[Distributed]", 
     RowBox[{"ExampleDistribution", "[", "a", "]"}]}]}], "]"}], "\[Equal]", 
  RowBox[{"Probability", "[", 
   RowBox[{
    RowBox[{"y", ">", "1"}], ",", 
    RowBox[{"y", "\[Distributed]", 
     RowBox[{"ExampleDistribution", "[", "a", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.526742318203255*^9, {3.5267429607066755`*^9, 3.5267429642466755`*^9}}],

Cell["Powering transformation:", "Text",
 CellChangeTimes->{{3.5267429818646755`*^9, 3.5267430084606752`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Refine", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CDF", "[", 
        RowBox[{
         RowBox[{"ExampleDistribution", "[", "a", "]"}], ",", "x"}], "]"}], 
       ",", 
       RowBox[{"CDF", "[", 
        RowBox[{
         RowBox[{"ExampleDistribution", "[", "2", "]"}], ",", "y"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{"0", "<", "x", "<", "1"}], "&&", 
      RowBox[{"0", "<", "y", "<", "1"}]}]}], "]"}], "/.", 
   RowBox[{"y", "\[Rule]", 
    SuperscriptBox["x", 
     RowBox[{"a", "/", "2"}]]}]}], "//", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"#", ",", 
     RowBox[{
      RowBox[{"0", "<", "x", "<", "1"}], "&&", 
      RowBox[{"a", ">", "0"}]}]}], "]"}], "&"}]}]], "Input",
 CellChangeTimes->{{3.5267423821016445`*^9, 3.526742429938428*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"4", " ", "a", " ", 
       RowBox[{"ArcTanh", "[", 
        SuperscriptBox["x", "a"], "]"}], " ", 
       RowBox[{"Log", "[", "x", "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
         SuperscriptBox["x", "a"]}], "]"}]}], "+", 
      RowBox[{"PolyLog", "[", 
       RowBox[{"2", ",", 
        SuperscriptBox["x", 
         RowBox[{"2", " ", "a"}]]}], "]"}]}], 
     SuperscriptBox["\[Pi]", "2"]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"4", " ", "a", " ", 
       RowBox[{"ArcTanh", "[", 
        SuperscriptBox["x", "a"], "]"}], " ", 
       RowBox[{"Log", "[", "x", "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
         SuperscriptBox["x", "a"]}], "]"}]}], "+", 
      RowBox[{"PolyLog", "[", 
       RowBox[{"2", ",", 
        SuperscriptBox["x", 
         RowBox[{"2", " ", "a"}]]}], "]"}]}], 
     SuperscriptBox["\[Pi]", "2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.526742406782112*^9, 3.526742431055539*^9}, 
   3.5273500595770817`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Strategy",
  FontWeight->"Bold"],
 ": Generate RNG from ExampleDistribution[2] on 0<x<1, then map to positive \
line for parameter ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 "."
}], "Program",
 CellChangeTimes->{{3.526743056712675*^9, 3.5267431242986755`*^9}}],

Cell["Find the maximum of the truncated PDF:", "Text",
 CellChangeTimes->{{3.5267431338516755`*^9, 3.526743138684675*^9}, {
  3.527350178476082*^9, 3.5273501827680817`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tpdf", "=", 
  RowBox[{"PDF", "[", 
   RowBox[{
    RowBox[{"TruncatedDistribution", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], ",", 
      RowBox[{"ExampleDistribution", "[", "2", "]"}]}], "]"}], ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5273501466950817`*^9, 3.527350148889082*^9}, 
   3.527350210265082*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        FractionBox["8", 
         SuperscriptBox["\[Pi]", "2"]], 
        RowBox[{"x", "\[Equal]", "1"}]},
       {
        FractionBox[
         RowBox[{"32", " ", "x", " ", 
          RowBox[{"Log", "[", "x", "]"}]}], 
         RowBox[{
          SuperscriptBox["\[Pi]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["x", "4"]}], ")"}]}]], 
        RowBox[{"0", "<", "x", "<", "1"}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.527350210550082*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Convergents", "[", 
  RowBox[{"NMaxValue", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tpdf", ",", 
      RowBox[{"0", "<", "x", "<", "1"}]}], "}"}], ",", "x"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.52674250856729*^9, 3.5267425458680196`*^9}, {
  3.5267425844718795`*^9, 3.526742589926425*^9}, {3.5267426331887507`*^9, 
  3.5267426398564177`*^9}, {3.526752744440836*^9, 3.5267527503284245`*^9}, {
  3.5268309988515244`*^9, 3.526831006916331*^9}, {3.527350144571082*^9, 
  3.527350152767082*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{"ForAll", "[", 
      RowBox[{"x", ",", 
       RowBox[{"0", "<", "x", "<", "1"}], ",", 
       RowBox[{"tpdf", "<=", "#"}]}], "]"}], ",", "Reals"}], "]"}], "&"}], "/@",
   "%"}]], "Input",
 CellChangeTimes->{{3.5267426815576754`*^9, 3.5267427372616754`*^9}, 
   3.5267527562310147`*^9, 3.5268310182554646`*^9, {3.527350099741082*^9, 
   3.5273501203130817`*^9}, {3.527350156165082*^9, 3.527350156975082*^9}}],

Cell[BoxData[
 RowBox[{"Pick", "[", 
  RowBox[{"%%", ",", "%", ",", "True"}], "]"}]], "Input",
 CellChangeTimes->{{3.5267427444926753`*^9, 3.5267427521296754`*^9}, {
  3.527350106370082*^9, 3.527350106859082*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"tpdf", ",", 
     FractionBox["11", "9"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Evaluated", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.526742449198354*^9, 3.526742495677001*^9}, {
  3.526742551703603*^9, 3.526742558715304*^9}, {3.526742597846217*^9, 
  3.5267425987543077`*^9}, {3.5267426566646757`*^9, 3.5267426709716754`*^9}, {
  3.5267527724266343`*^9, 3.5267527749528866`*^9}, {3.5268310325068893`*^9, 
  3.526831040971736*^9}, {3.527350164724082*^9, 3.527350165391082*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Random number generation by Acceptance\[Hyphen]Rejection\
\>", "Subsubsection",
 CellChangeTimes->{{3.526742346722107*^9, 3.5267423580662413`*^9}}],

Cell["\<\
Random`RandomRealRejection[ densityFunc, { hatFunc, hatRandomVector }, len, \
prec ]
\tgenerates random variates from continuous univariate density. The density \
need not be normalized, 
\tas long as densityFunc <= hatFunc, and hatRandomVector draws from \
distribution with density ~ to hatFunc.\
\>", "Program",
 CellChangeTimes->{{3.5268308548751283`*^9, 3.5268309483944793`*^9}}],

Cell["", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"Random`RandomRealRejection", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Function", "[", 
        RowBox[{"x", ",", 
         RowBox[{
          FractionBox["32", 
           RowBox[{"Pi", "^", "2"}]], 
          FractionBox[
           RowBox[{"x", " ", 
            RowBox[{"Log", "[", "x", "]"}]}], 
           RowBox[{
            RowBox[{"x", "^", "4"}], "-", "1"}]]}], ",", "Listable"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["11", "9"], "&"}], ",", 
         RowBox[{"Function", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"len", ",", "prec"}], "}"}], ",", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"1", ",", "len", ",", 
             RowBox[{"WorkingPrecision", "\[Rule]", "prec"}]}], "]"}]}], 
          "]"}]}], "}"}], ",", 
       RowBox[{"10", "^", "5"}], ",", "MachinePrecision"}], "]"}], ",", 
     "Automatic", ",", "\"\<PDF\>\""}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      FractionBox["32", 
       RowBox[{"Pi", "^", "2"}]], 
      FractionBox[
       RowBox[{"x", " ", 
        RowBox[{"Log", "[", "x", "]"}]}], 
       RowBox[{
        RowBox[{"x", "^", "4"}], "-", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5267522470190988`*^9, 3.5267523085922556`*^9}, 
   3.526752645803973*^9, {3.52675270497689*^9, 3.526752716101002*^9}, {
   3.5267527959829893`*^9, 3.526752859971388*^9}}],

Cell["We can now code the generator for ExampleDistribution:", "Text",
 CellChangeTimes->{{3.5273502669314566`*^9, 3.527350283153079*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Random`DistributionVector", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
     "Statistics`Library`DistributionNParameterQ"}], ",", "len_Integer", ",", 
    "prec_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "u", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"u", "=", 
      RowBox[{"Random`RandomRealRejection", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Function", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           FractionBox["32", 
            RowBox[{"Pi", "^", "2"}]], 
           FractionBox[
            RowBox[{"x", " ", 
             RowBox[{"Log", "[", "x", "]"}]}], 
            RowBox[{
             RowBox[{"x", "^", "4"}], "-", "1"}]]}], ",", "Listable"}], "]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox["11", "9"], "&"}], ",", 
          RowBox[{"Function", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"le", ",", "pr"}], "}"}], ",", 
            RowBox[{"RandomReal", "[", 
             RowBox[{"1", ",", "le", ",", 
              RowBox[{"WorkingPrecision", "\[Rule]", "pr"}]}], "]"}]}], 
           "]"}]}], "}"}], ",", "len", ",", "prec"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"u", "^", 
        RowBox[{"RandomChoice", "[", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "2"}], "]"}], ",", "len"}], 
         "]"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"2", "/", "a"}], ")"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5268287368143435`*^9, 3.5268288334550066`*^9}, {
   3.526828864487109*^9, 3.526828867745435*^9}, 3.526830700655708*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{
   RowBox[{"sample", "=", 
    RowBox[{"RandomVariate", "[", 
     RowBox[{
      RowBox[{"ExampleDistribution", "[", "3", "]"}], ",", 
      RowBox[{"10", "^", "6"}]}], "]"}]}], ";"}], "]"}]], "Input",
 CellChangeTimes->{{3.5268307297036123`*^9, 3.526830752262868*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.7580758`7.331257626404884", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{{3.5268307527919207`*^9, 3.526830758509493*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Histogram", "[", 
    RowBox[{"sample", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3", ",", "0.05"}], "}"}], ",", "\"\<PDF\>\""}], 
    "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"PDF", "[", 
      RowBox[{
       RowBox[{"TruncatedDistribution", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "3"}], "}"}], ",", 
         RowBox[{"ExampleDistribution", "[", "3", "]"}]}], "]"}], ",", "x"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "3"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"Evaluated", "\[Rule]", "True"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5268307621808596`*^9, 3.5268308215337944`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.7]], {}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     EdgeForm[Opacity[0.7]], RectangleBox[{0., 0.}, {0.05, 0.01122381244047371},
      RoundingRadius->0], RectangleBox[{0.05, 0.}, {0.1, 0.0590051854013475},
      RoundingRadius->0], RectangleBox[{0.1, 0.}, {0.15000000000000002`, 0.12545015504895182`},
      RoundingRadius->0], RectangleBox[{0.15000000000000002`, 0.}, {0.2, 0.2062829833107254},
      RoundingRadius->0], RectangleBox[{0.2, 0.}, {0.25, 0.2966507074743109},
      RoundingRadius->0], RectangleBox[{0.25, 0.}, {0.30000000000000004`, 0.37893728668075494`},
      RoundingRadius->0], RectangleBox[{0.30000000000000004`, 0.}, {0.35000000000000003`, 0.46443066944162076`},
      RoundingRadius->0], RectangleBox[{0.35000000000000003`, 0.}, {0.4, 0.5356003296594055},
      RoundingRadius->0], RectangleBox[{0.4, 0.}, {0.45, 0.6102119590256022},
      RoundingRadius->0], RectangleBox[{0.45, 0.}, {0.5, 0.664855891592937},
      RoundingRadius->0], RectangleBox[{0.5, 0.}, {0.55, 0.7010500143771686},
      RoundingRadius->0], RectangleBox[{0.55, 0.}, {0.6000000000000001, 0.7398950947663891},
      RoundingRadius->0], RectangleBox[{0.6000000000000001, 0.}, {0.65, 0.7710224679346379},
      RoundingRadius->0], RectangleBox[{0.65, 0.}, {0.7000000000000001, 0.7757471585048165},
      RoundingRadius->0], RectangleBox[{0.7000000000000001, 0.}, {0.75, 0.7732886091130955},
      RoundingRadius->0], RectangleBox[{0.75, 0.}, {0.8, 0.7634330328558396},
      RoundingRadius->0], RectangleBox[{0.8, 0.}, {0.8500000000000001, 0.7418405555894045},
      RoundingRadius->0], RectangleBox[{0.8500000000000001, 0.}, {0.9, 0.7208253029627668},
      RoundingRadius->0], RectangleBox[{0.9, 0.}, {0.9500000000000001, 0.6923916447802319},
      RoundingRadius->0], RectangleBox[{0.9500000000000001, 0.}, {1., 0.6685544050257035},
      RoundingRadius->0], RectangleBox[{1., 0.}, {1.05, 0.6384745876852324},
      RoundingRadius->0], RectangleBox[{1.05, 0.}, {1.1, 0.5976840464729967},
      RoundingRadius->0], RectangleBox[{1.1, 0.}, {1.1500000000000001`, 0.5729061443425032},
      RoundingRadius->0], RectangleBox[{1.1500000000000001`, 0.}, {1.2000000000000002`, 0.5346169099027158},
      RoundingRadius->0], RectangleBox[{1.2000000000000002`, 0.}, {1.25, 0.49619940332075374`},
      RoundingRadius->0], RectangleBox[{1.25, 0.}, {1.3, 0.4655209826501234},
      RoundingRadius->0], RectangleBox[{1.3, 0.}, {1.35, 0.4351632423349374},
      RoundingRadius->0], RectangleBox[{1.35, 0.}, {1.4000000000000001`, 0.40613098082224547`},
      RoundingRadius->0], RectangleBox[{1.4000000000000001`, 0.}, {1.4500000000000002`, 0.37615805693359},
      RoundingRadius->0], RectangleBox[{1.4500000000000002`, 0.}, {1.5, 0.352064272894708},
      RoundingRadius->0], RectangleBox[{1.5, 0.}, {1.55, 0.33455512548756744`},
      RoundingRadius->0], RectangleBox[{1.55, 0.}, {1.6, 0.30355602446149726`},
      RoundingRadius->0], RectangleBox[{1.6, 0.}, {1.6500000000000001`, 0.28801371656773656`},
      RoundingRadius->0], RectangleBox[{1.6500000000000001`, 0.}, {1.7000000000000002`, 0.26563022775787754`},
      RoundingRadius->0], RectangleBox[{1.7000000000000002`, 0.}, {1.75, 0.24561977357829123`},
      RoundingRadius->0], RectangleBox[{1.75, 0.}, {1.8, 0.23508007922942628`},
      RoundingRadius->0], RectangleBox[{1.8, 0.}, {1.85, 0.21765644658373853`},
      RoundingRadius->0], RectangleBox[{1.85, 0.}, {1.9000000000000001`, 0.20194310916707536`},
      RoundingRadius->0], RectangleBox[{1.9000000000000001`, 0.}, {1.9500000000000002`, 0.19084756886877852`},
      RoundingRadius->0], 
     RectangleBox[{1.9500000000000002`, 0.}, {2., 0.17564732002082348`},
      RoundingRadius->0], RectangleBox[{2., 0.}, {2.0500000000000003`, 0.1648510813876044},
      RoundingRadius->0], RectangleBox[{2.0500000000000003`, 0.}, {2.1, 0.15600030357740372`},
      RoundingRadius->0], RectangleBox[{2.1, 0.}, {2.15, 0.14687160279248507`},
      RoundingRadius->0], RectangleBox[{2.15, 0.}, {2.2, 0.13387335905189712`},
      RoundingRadius->0], RectangleBox[{2.2, 0.}, {2.25, 0.1295548635986113},
      RoundingRadius->0], RectangleBox[{2.25, 0.}, {2.3000000000000003`, 0.12258541054033506`},
      RoundingRadius->0], RectangleBox[{2.3000000000000003`, 0.}, {2.35, 0.11219536702401188`},
      RoundingRadius->0], RectangleBox[{2.35, 0.}, {2.4000000000000004`, 0.10319493838126916`},
      RoundingRadius->0], RectangleBox[{2.4000000000000004`, 0.}, {2.45, 0.09827783959782442},
      RoundingRadius->0], RectangleBox[{2.45, 0.}, {2.5, 0.09447243271324476},
      RoundingRadius->0], RectangleBox[{2.5, 0.}, {2.5500000000000003`, 0.08987601428524042},
      RoundingRadius->0], RectangleBox[{2.5500000000000003`, 0.}, {2.6, 0.08532235323796329},
      RoundingRadius->0], RectangleBox[{2.6, 0.}, {2.6500000000000004`, 0.07707017875791906},
      RoundingRadius->0], RectangleBox[{2.6500000000000004`, 0.}, {2.7, 0.07362820960950779},
      RoundingRadius->0], RectangleBox[{2.7, 0.}, {2.75, 0.06909592725259268},
      RoundingRadius->0], RectangleBox[{2.75, 0.}, {2.8000000000000003`, 0.07033589129363488},
      RoundingRadius->0], RectangleBox[{2.8000000000000003`, 0.}, {2.85, 0.061698900387061405`},
      RoundingRadius->0], RectangleBox[{2.85, 0.}, {2.9000000000000004`, 0.06315265133173173},
      RoundingRadius->0], RectangleBox[{2.9000000000000004`, 0.}, {2.95, 0.05902656409171052},
      RoundingRadius->0], RectangleBox[{2.95, 0.}, {3., 0.05475082601914909},
      RoundingRadius->0]}, {}, {}}, {{{}, {}, 
     {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV1Xk4VPsfB3C5kjapUBRdEiFaSCm8FSokVKRtRAolW1JSjZCyF5HsZUso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       "]], LineBox[CompressedData["
1:eJwBcQOO/CFib1JlAgAAADYAAAACAAAAJg8ITXib8D/Y6IqYNv7jP7ZwgKuO
n/E/Y2XqWSme4j/UJZMHUZLyP/ipQjEVVeE/JIPTKF2Z8z81UNErh/HfPzlQ
3zSfm/Q/YtQGt4ti3T/dcIU+jYz1P4L4LkhpINs/sjlZDcWR9j8498N8w9XY
PxZWx9mohfc/ad9kOXTZ1j8/4gCRwnT4P1cS8uYtDNU/mRZoDSZ4+T/twUJy
MUDTP4KeaYc1avo/0YKCqjK30T+dzpjGjnD7P9MWWFBqMtA/fW6T8B1y/D8X
LaPIU6/NP+thKBhZYv0/maJr5fthyz+L/eoE3mb+P8UAg/hTHMk/uuxH7w5a
/z/FSiBeoy7HP9YlOOI6JABAXzSkdLh0xT9oKWMvk6UAQHU2j5z7v8M/wVZb
e0EeAUD0NZMO7kzCPzNY6qkUoQFAZ4nAP5LewD9sg0bXPRsCQEMwxu3pTb8/
iGYI+gGTAkDJyjU6lR69P70dYf/qFANAAftKEjX0uj+5/oYDKo4DQGtoAOlC
G7k/zrND6o0RBEDciOZqeka3P8UgZsaMkgRA8IygPzWitT+Et1Wh4QoFQLhE
7hBwOrQ/XCLcXluNBUDzT5jTMdSyP/u2LxsrBwZAf2HiluOgsT98A+nMlX4G
QJPh71++irA/FiQ5YSUAB0B5SFuOCumuP3duVvQKeQdAzp7gQBIKrT8cNmTI
JnsHQKOleWUKAq0/wP1xnEJ9B0CL+bBKBfqsPwqNjUR6gQdA/WONUgPqrD+e
q8SU6YkHQFsxHTkgyqw/xugyNciaB0ABgjhs3IqsPxRjD3aFvAdAHYkV2VYO
rD+5Kh1Kob4HQLZF6fWkBqw/XvIqHr3AB0CpYuGw9f6rP6iBRsb0xAdAPbAP
/Z7vqz87oH0WZM0HQBaGNdEQ0as/Yt3rtkLeB0AldLWAcJSrPwel+Ype4AdA
j09DA+iMqz+sbAdfeuIHQFxmbxNihas/9vsiB7LmB0AK45DYXXarP4oaWlch
7wdA+uSY2XNYqz8v4mcrPfEHQOcytaz/UKs/1Kl1/1jzB0Anx1gFjkmrPx45
kaeQ9wdAld8yQ7I6qz/DAJ97rPkHQK0RaSZIM6s/aMisT8j7B0CD5SWL4Cur
PwyQuiPk/QdAkVBqcHskqz+xV8j3//8HQHW6N9UYHas/r3SUKg==
       "]]}, {}}, {{}, {}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{0., 0.},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRange->{{0., 3.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.526830793315973*^9, 3.526830825869228*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Another useful property", "Subsubsection",
 CellChangeTimes->{{3.5267431588746758`*^9, 3.526743163219675*^9}}],

Cell["We are going to establish (in a round-about way) that:", "Text",
 CellChangeTimes->{{3.5267508313535323`*^9, 3.526750854202849*^9}, {
  3.5267513213518486`*^9, 3.5267513277878485`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExampleDistribution", "[", "1", "]"}], "\[Equal]", 
  RowBox[{"TransformedDistribution", "[", 
   RowBox[{
    RowBox[{"Abs", "[", 
     RowBox[{"u", "/", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Distributed]", 
       RowBox[{"CauchyDistribution", "[", 
        RowBox[{"0", ",", "1"}], "]"}]}], ",", 
      RowBox[{"v", "\[Distributed]", 
       RowBox[{"CauchyDistribution", "[", 
        RowBox[{"0", ",", "1"}], "]"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.526750855003849*^9, 3.5267508954888487`*^9}}],

Cell[TextData[{
 "First compute characteristic function of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "/", "v"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.5267506959839964`*^9, 3.526750720387437*^9}, {
  3.5267509811128488`*^9, 3.5267509944628487`*^9}, {3.5267513334028487`*^9, 
  3.526751368425849*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cf1", "=", 
  RowBox[{"Expectation", "[", 
   RowBox[{
    RowBox[{"CharacteristicFunction", "[", 
     RowBox[{
      RowBox[{"CauchyDistribution", "[", 
       RowBox[{"0", ",", "1"}], "]"}], ",", 
      RowBox[{"t", "/", "v"}]}], "]"}], ",", 
    RowBox[{"v", "\[Distributed]", 
     RowBox[{"CauchyDistribution", "[", 
      RowBox[{"0", ",", "1"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5267482138658*^9, 3.5267482274021535`*^9}, {
   3.5267497332267303`*^9, 3.526749737680176*^9}, 3.5267506661410127`*^9, {
   3.526751129644849*^9, 3.5267511305608487`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"\[Pi]", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"t", " ", 
      RowBox[{"Sign", "[", "t", "]"}]}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"CosIntegral", "[", 
     RowBox[{"t", " ", 
      RowBox[{"Sign", "[", "t", "]"}]}], "]"}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"t", " ", 
      RowBox[{"Sign", "[", "t", "]"}]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"t", " ", 
      RowBox[{"Sign", "[", "t", "]"}]}], "]"}], " ", 
    RowBox[{"SinIntegral", "[", 
     RowBox[{"t", " ", 
      RowBox[{"Sign", "[", "t", "]"}]}], "]"}]}]}], "\[Pi]"]], "Output",
 CellChangeTimes->{{3.5267507234777455`*^9, 3.526750751296527*^9}, 
   3.526750934380849*^9, 3.5267510096938486`*^9, 3.5267511348038487`*^9}]
}, Open  ]],

Cell[TextData[{
 "Now compute characteristic function of  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"ExampleDistribution", "[", "1", "]"}], TraditionalForm]]],
 " symmetricallyt extended to  negative real axis:"
}], "Text",
 CellChangeTimes->{{3.526751378544849*^9, 3.526751420699849*^9}, {
  3.526751463052849*^9, 3.526751491058849*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cf2", "=", 
  RowBox[{"Expectation", "[", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"t", " ", "x"}], "]"}], ",", 
    RowBox[{"x", "\[Distributed]", 
     RowBox[{"ExampleDistribution", "[", "1", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5267509365208488`*^9, 3.5267509679488487`*^9}, {
  3.5267511322008486`*^9, 3.526751132908849*^9}, {3.526751228546849*^9, 
  3.5267512401368484`*^9}, {3.5267512708368487`*^9, 3.5267512761208487`*^9}, {
  3.5267514540018487`*^9, 3.526751457704849*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"\[Pi]", " ", "t"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Pi]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"Abs", "[", "t", "]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Log", "[", "4", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Log", "[", 
            RowBox[{"Abs", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"Abs", "[", "t", "]"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Abs", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"CosIntegral", "[", "t", "]"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Log", "[", "4", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Log", "[", "t", "]"}]}]}], ")"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        RowBox[{"SinIntegral", "[", "t", "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.526751002175849*^9, 3.5267510371678486`*^9, 
  3.5267511633498487`*^9, 3.5267512577268486`*^9, 3.526751294675849*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"cf1", "\[Equal]", "cf2"}], ",", 
   RowBox[{"t", "\[Element]", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5267512998848486`*^9, 3.5267513093868484`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5267513104818487`*^9}]
}, Open  ]],

Cell["We thus established that", "Text",
 CellChangeTimes->{{3.526751498722849*^9, 3.526751519220849*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExampleDistribution", "[", "a", "]"}], "\[Equal]", 
  RowBox[{"TransformedDistribution", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"Abs", "[", 
      FractionBox["u", "v"], "]"}], 
     RowBox[{"1", "/", "a"}]], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Distributed]", 
       RowBox[{"CauchyDistribution", "[", 
        RowBox[{"0", ",", "1"}], "]"}]}], ",", 
      RowBox[{"v", "\[Distributed]", 
       RowBox[{"CauchyDistribution", "[", 
        RowBox[{"0", ",", "1"}], "]"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5267515209888487`*^9, 3.5267515538628488`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Faster generation", "Subsubsection",
 CellChangeTimes->{{3.5267431655086756`*^9, 3.526743170717675*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], "[", 
    "\"\<RandomType\>\"", "]"}], "=", "RandomReal"}], ";"}]], "Input",
 CellChangeTimes->{{3.526817900072726*^9, 3.526817907007419*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Random`DistributionVector", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ExampleDistribution", "[", "a_", "]"}], "?", 
     "Statistics`Library`DistributionNParameterQ"}], ",", "len_Integer", ",", 
    "prec_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"RandomVariate", "[", 
       RowBox[{
        RowBox[{"CauchyDistribution", "[", 
         RowBox[{"0", ",", "1"}], "]"}], ",", "len", ",", 
        RowBox[{"WorkingPrecision", "\[Rule]", "prec"}]}], "]"}], "/", 
      RowBox[{"RandomVariate", "[", 
       RowBox[{
        RowBox[{"CauchyDistribution", "[", 
         RowBox[{"0", ",", "1"}], "]"}], ",", "len", ",", 
        RowBox[{"WorkingPrecision", "\[Rule]", "prec"}]}], "]"}]}], "]"}], 
    ")"}], "^", 
   RowBox[{"(", 
    RowBox[{"1", "/", "a"}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526735532719572*^9, 3.526735539381238*^9}, {
  3.5267356411714163`*^9, 3.5267356703353324`*^9}, {3.526735704441743*^9, 
  3.526735767842082*^9}, {3.526735803494647*^9, 3.526735831241421*^9}, {
  3.526735910044301*^9, 3.526735914106707*^9}, {3.5267406037828255`*^9, 
  3.5267406052199697`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Likelihood/LogLikelihod", "Subsection",
 CellChangeTimes->{{3.5267542578209095`*^9, 3.5267542614721184`*^9}, {
  3.5268133346612067`*^9, 3.5268133440971503`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"LogLikelihood", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], ",", 
    RowBox[{"x_", "?", "Statistics`Library`AdmissibleVectorInputQ"}]}], "]"}],
   ":=", "\[IndentingNewLine]", 
  RowBox[{"Piecewise", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"logx", "=", 
           RowBox[{"Log", "[", "x", "]"}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"2", 
           RowBox[{"Length", "[", "x", "]"}], 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "a"}], ")"}], "/", "Pi"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", "1"}], ")"}], 
           RowBox[{"Total", "[", "logx", "]"}]}], "+", 
          RowBox[{"Total", "[", 
           RowBox[{"Log", "[", 
            RowBox[{"logx", "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "^", 
                RowBox[{"(", 
                 RowBox[{"2", "a"}], ")"}]}], "-", "1"}], ")"}]}], "]"}], 
           "]"}]}]}], "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{
        RowBox[{"Min", "[", "x", "]"}], ">", "0"}]}], "}"}], "}"}], ",", 
    RowBox[{"-", "Infinity"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5267542686425285`*^9, 3.526754292198876*^9}, {
  3.526754579474307*^9, 3.5267547008812513`*^9}, {3.526754779958774*^9, 
  3.526754821947176*^9}, {3.5267548581292453`*^9, 3.5267548797714834`*^9}, {
  3.5267549175706453`*^9, 3.5267549315884466`*^9}, {3.5267561454233613`*^9, 
  3.5267561497436085`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Likelihood", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], ",", 
    RowBox[{"x_", "?", "Statistics`Library`AdmissibleVectorInputQ"}]}], "]"}],
   ":=", "\[IndentingNewLine]", 
  RowBox[{"Piecewise", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"logx", "=", 
           RowBox[{"Log", "[", "x", "]"}]}], "}"}], ",", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"2", 
            RowBox[{"Length", "[", "x", "]"}], 
            RowBox[{"Log", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "a"}], ")"}], "/", "Pi"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "1"}], ")"}], 
            RowBox[{"Total", "[", "logx", "]"}]}], "+", 
           RowBox[{"Total", "[", 
            RowBox[{"Log", "[", 
             RowBox[{"logx", "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", 
                 RowBox[{"(", 
                  RowBox[{"2", "a"}], ")"}]}], "-", "1"}], ")"}]}], "]"}], 
            "]"}]}], "]"}]}], "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{
        RowBox[{"Min", "[", "x", "]"}], ">", "0"}]}], "}"}], "}"}], ",", 
    "0"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5267542686425285`*^9, 3.526754292198876*^9}, {
   3.526754579474307*^9, 3.5267547008812513`*^9}, {3.526754779958774*^9, 
   3.526754821947176*^9}, {3.5267548581292453`*^9, 3.5267548797714834`*^9}, {
   3.5267549175706453`*^9, 3.526754945822261*^9}, 3.526756156375988*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Parameter estimation", "Subsection",
 CellChangeTimes->{{3.5268133473364744`*^9, 3.5268133500587463`*^9}}],

Cell[CellGroupData[{

Cell["Finding out ML-equations:", "Subsubsection",
 CellChangeTimes->{{3.5268168216378837`*^9, 3.5268168277034903`*^9}, {
  3.5268169306227813`*^9, 3.5268169337950983`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Refine", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"LogLikelihood", "[", 
       RowBox[{
        RowBox[{"ExampleDistribution", "[", "a", "]"}], ",", 
        RowBox[{"{", "x", "}"}]}], "]"}], ",", "a"}], "]"}], ",", 
    RowBox[{"x", ">", "1"}]}], "]"}], "//", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"#", ",", 
     RowBox[{
      RowBox[{"x", ">", "0"}], "&&", 
      RowBox[{"a", ">", "0"}]}]}], "]"}], "&"}]}]], "Input",
 CellChangeTimes->{{3.526814793948004*^9, 3.5268148280320044`*^9}, {
  3.526816083769793*^9, 3.526816100598793*^9}, {3.526816304265793*^9, 
  3.526816304764793*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["2", "a"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["x", 
       RowBox[{"2", " ", "a"}]]}], ")"}], " ", 
    RowBox[{"Log", "[", "x", "]"}]}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SuperscriptBox["x", 
     RowBox[{"2", " ", "a"}]]}]]}]], "Output",
 CellChangeTimes->{{3.526814820393004*^9, 3.526814828570004*^9}, 
   3.5268158102717524`*^9, {3.526816085478793*^9, 3.526816101021793*^9}, 
   3.5268163054367933`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      FractionBox["2", "a"], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["x", 
           RowBox[{"2", " ", "a"}]]}], ")"}], " ", 
        RowBox[{"Log", "[", "x", "]"}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["x", 
         RowBox[{"2", " ", "a"}]]}]]}], ",", "a"}], "]"}], "//", "Simplify"}],
   "//", 
  RowBox[{
   RowBox[{"Apart", "[", 
    RowBox[{"#", ",", "a"}], "]"}], "&"}]}]], "Input",
 CellChangeTimes->{{3.526816114243793*^9, 3.526816117303793*^9}, {
  3.526816196301793*^9, 3.5268162012347927`*^9}, {3.5268163495466795`*^9, 
  3.5268163773904634`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["2", 
    SuperscriptBox["a", "2"]]}], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["x", 
     RowBox[{"2", " ", "a"}]], " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", "x", "]"}], "2"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["x", 
       RowBox[{"2", " ", "a"}]]}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{{3.526816196974793*^9, 3.526816201942793*^9}, {
  3.526816351310856*^9, 3.5268163776684914`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expectation", "[", 
  RowBox[{
   RowBox[{"x", "\[Conditioned]", 
    RowBox[{"0", "<", "x", "<", "1"}]}], ",", 
   RowBox[{"x", "\[Distributed]", 
    RowBox[{"ExampleDistribution", "[", "a", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5268167817538958`*^9, 3.526816795757296*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"PolyGamma", "[", 
    RowBox[{"1", ",", 
     FractionBox[
      RowBox[{"1", "+", "a"}], 
      RowBox[{"2", " ", "a"}]]}], "]"}]}], 
  SuperscriptBox["\[Pi]", "2"]]], "Output",
 CellChangeTimes->{3.5268168058553057`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Code", "Subsubsection",
 CellChangeTimes->{{3.527253041696248*^9, 3.5272530421702957`*^9}}],

Cell["\<\
Quick check that data are valid is done before expensive estimation starts:\
\>", "Text",
 CellChangeTimes->{{3.5272530509771767`*^9, 3.5272530904041185`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Statistics`Library`AcceptableDistributedDataQ", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], ",", "data_"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"VectorQ", "[", 
    RowBox[{"data", ",", "NumericQ"}], "]"}], "&&", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Positive", "[", 
      RowBox[{"Min", "[", "data", "]"}], "]"}], "===", "True"}], 
    ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.52681345650639*^9, 3.52681348230997*^9}, {
  3.5268137232220592`*^9, 3.526813771013838*^9}}],

Cell["\<\
Declares method used. Possible methods indicate the solve used: \
\[OpenCurlyDoubleQuote]FindRoot\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]FindMaximum\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]NMinimize\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]Solve\[CloseCurlyDoubleQuote], etc.\
\>", "Text",
 CellChangeTimes->{{3.5272530994320216`*^9, 3.5272531914272203`*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", 
  RowBox[{"Statistics`Library`DefaultEstimator", "[", 
   RowBox[{
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], ",", 
    "\"\<MaximumLikelihood\>\""}], "]"}], ":=", "\"\<FindRoot\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.52681380173691*^9, 3.526813851115847*^9}}],

Cell[TextData[{
 "Estimation code. ",
 StyleBox["Returns a list of rules, or $Failed",
  FontWeight->"Bold"],
 ".  \[LineSeparator]\nFirst get an approximation via truncated moments, then \
find root of ML equation."
}], "Text",
 CellChangeTimes->{{3.5272531978938665`*^9, 3.527253296687745*^9}}],

Cell[BoxData[
 RowBox[{"ExampleDistribution", "/:", "\[IndentingNewLine]", 
  RowBox[{"Statistics`Library`DistributionParameterEstimation", "[", 
   RowBox[{"data_", ",", 
    RowBox[{"ExampleDistribution", "[", "a_", "]"}], ",", "start_", ",", 
    "optlist_", ",", "\"\<MaximumLikelihood\>\"", ",", "caller_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "aa", ",", "f", ",", "j", ",", "a0", ",", "fopts", ",", "res", ",", 
      RowBox[{"logx", "=", 
       RowBox[{"Log", "[", "data", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "aa_Real", "]"}], "=", 
      RowBox[{"Block", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"y", "=", 
          RowBox[{"data", "^", 
           RowBox[{"(", 
            RowBox[{"2", "aa"}], ")"}]}]}], "}"}], ",", 
        RowBox[{
         RowBox[{"2", "/", "aa"}], "-", 
         RowBox[{"Mean", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y", "+", "1"}], ")"}], 
           RowBox[{"logx", "/", 
            RowBox[{"(", 
             RowBox[{"y", "-", "1"}], ")"}]}]}], "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"j", "[", "aa_Real", "]"}], "=", 
      RowBox[{"Block", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"y", "=", 
          RowBox[{"data", "^", 
           RowBox[{"(", 
            RowBox[{"2", "aa"}], ")"}]}]}], "}"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "/", 
          RowBox[{"aa", "^", "2"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"Mean", "[", 
           RowBox[{"y", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"logx", "/", 
               RowBox[{"(", 
                RowBox[{"y", "-", "1"}], ")"}]}], ")"}], "^", "2"}]}], 
           "]"}]}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"fopts", "=", 
      RowBox[{"FilterRules", "[", 
       RowBox[{"optlist", ",", 
        RowBox[{"Options", "@", "FindRoot"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"a0", "=", 
      RowBox[{"a", "/.", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"PolyGamma", "[", 
           RowBox[{"1", ",", 
            FractionBox[
             RowBox[{"1", "+", "a"}], 
             RowBox[{"2", " ", "a"}]]}], "]"}], "==", 
          RowBox[{
           RowBox[{
            RowBox[{"Pi", "^", "2"}], "/", "2"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Total", "[", "#", "]"}], "/", 
               RowBox[{"Total", "[", 
                RowBox[{"Sign", "[", "#", "]"}], "]"}]}], "&"}], "[", 
             RowBox[{"Clip", "[", 
              RowBox[{"data", ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}]}], "]"}], "]"}], ")"}]}]}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"a", ",", "1"}], "}"}], ",", 
         RowBox[{"Evaluate", "[", "fopts", "]"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"NumberQ", "[", "a0", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"res", "=", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", "a", "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"a", ",", "a0"}], "}"}], ",", 
           RowBox[{"Jacobian", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{"j", "[", "a", "]"}], "}"}], "}"}]}], ",", 
           RowBox[{"Evaluate", "[", "fopts", "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"ListQ", "[", "res", "]"}], ",", "res", ",", 
          RowBox[{"res", "=", "$Failed"}]}], "]"}]}], "\[IndentingNewLine]", 
       ",", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", "$Failed"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Clear", "[", 
      RowBox[{"f", ",", "j"}], "]"}], ";", "\[IndentingNewLine]", "res"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5268133779495354`*^9, 3.5268134378475246`*^9}, {
   3.526813864919227*^9, 3.52681393585032*^9}, {3.526814039460004*^9, 
   3.526814062721004*^9}, {3.5268142828550043`*^9, 3.5268144393440037`*^9}, {
   3.526814480923004*^9, 3.526814537588004*^9}, {3.526814593741004*^9, 
   3.5268146603370037`*^9}, 3.526814740241004*^9, {3.5268148565680037`*^9, 
   3.526814858826004*^9}, {3.5268158012518506`*^9, 3.5268158017308984`*^9}, {
   3.526816069643793*^9, 3.526816074689793*^9}, {3.5268162131747932`*^9, 
   3.5268162413117933`*^9}, {3.526816312533793*^9, 3.5268163442141457`*^9}, {
   3.5268163965153756`*^9, 3.526816470245748*^9}, {3.5268165325239754`*^9, 
   3.5268165942831507`*^9}, {3.5268168373364534`*^9, 
   3.5268169066593847`*^9}, {3.5268170294236603`*^9, 3.5268171174628077`*^9}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Synergies", "Section",
 CellChangeTimes->{{3.526665822834399*^9, 3.5266658282413177`*^9}, {
  3.5267541976114655`*^9, 3.526754202978773*^9}, {3.5267674810967245`*^9, 
  3.526767482774821*^9}}],

Cell[CellGroupData[{

Cell["Generate a sample:", "Subsection",
 CellChangeTimes->{{3.5270100633402805`*^9, 3.5270100728111744`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"len", "=", "400"}], ",", 
       RowBox[{"di", "=", 
        RowBox[{"ChiDistribution", "[", "1", "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"RandomVariate", "[", 
           RowBox[{"di", ",", "len"}], "]"}], 
          RowBox[{"RandomVariate", "[", 
           RowBox[{"di", ",", "len"}], "]"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"RandomVariate", "[", 
           RowBox[{"di", ",", "len"}], "]"}], 
          RowBox[{"RandomVariate", "[", 
           RowBox[{"di", ",", "len"}], "]"}]}], ")"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5267542248790255`*^9, 3.526754252999634*^9}, {
   3.5267549542027407`*^9, 3.5267549897037706`*^9}, {3.526755877290025*^9, 
   3.5267559020664425`*^9}, {3.5267559349353223`*^9, 3.526755938193508*^9}, {
   3.5267560027402*^9, 3.526756004979328*^9}, {3.5267563525042057`*^9, 
   3.52675637111427*^9}, {3.526756476135277*^9, 3.52675651989478*^9}, {
   3.5267622767380524`*^9, 3.5267623112420263`*^9}, {3.526762803005153*^9, 
   3.5267628065423555`*^9}, {3.52676487753781*^9, 3.526764877702819*^9}, {
   3.5267649170000668`*^9, 3.5267649176901064`*^9}, 3.5267653416443553`*^9, {
   3.5267658159654846`*^9, 3.5267658163005037`*^9}, {3.5267658787030735`*^9, 
   3.526765879556122*^9}}],

Cell[CellGroupData[{

Cell["Explanation why this way", "Subsubsection",
 CellChangeTimes->{{3.527010082456558*^9, 3.527010099388251*^9}}],

Cell["\<\
Using representation of example distribution as quotient of Cauchy variables:\
\>", "Text",
 CellChangeTimes->{{3.5270101075030622`*^9, 3.527010137811093*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExampleDistribution", "[", "2", "]"}], "\[Equal]", 
  RowBox[{"TransformedDistribution", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"Abs", "[", 
      FractionBox["u", "v"], "]"}], 
     RowBox[{"1", "/", "2"}]], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"u", ",", "v"}], "}"}], "\[Distributed]", 
     RowBox[{"ProductDistribution", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"CauchyDistribution", "[", 
         RowBox[{"0", ",", "1"}], "]"}], ",", "2"}], "}"}], "]"}]}]}], "]"}], 
  "\[Equal]", "\[IndentingNewLine]", 
  RowBox[{"TransformedDistribution", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox["u", "2"], 
       SuperscriptBox["v", "2"]], ")"}], 
     RowBox[{"1", "/", "4"}]], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"u", ",", "v"}], "}"}], "\[Distributed]", 
     RowBox[{"ProductDistribution", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"CauchyDistribution", "[", 
         RowBox[{"0", ",", "1"}], "]"}], ",", "2"}], "}"}], "]"}]}]}], "]"}], 
  "==", 
  RowBox[{"TransformedDistribution", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z1", "2"], 
        SuperscriptBox["z4", "2"]}], 
       RowBox[{
        SuperscriptBox["z2", "2"], 
        SuperscriptBox["z3", "2"]}]], ")"}], 
     RowBox[{"1", "/", "4"}]], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z1", ",", "z2", ",", "z3", ",", "z4"}], "}"}], 
     "\[Distributed]", 
     RowBox[{"ProductDistribution", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NormalDistribution", "[", "]"}], ",", "4"}], "}"}], 
      "]"}]}]}], "]"}], "==", 
  RowBox[{"TransformedDistribution", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"x1", " ", "x4"}], 
       RowBox[{"x2", " ", "x3"}]], ")"}], 
     RowBox[{"1", "/", "2"}]], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4"}], "}"}], 
     "\[Distributed]", 
     RowBox[{"ProductDistribution", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ChiSquareDistribution", "[", "1", "]"}], ",", "4"}], "}"}], 
      "]"}]}]}], "]"}]}]], "DisplayFormula",
 CellChangeTimes->{{3.526817560226808*^9, 3.5268177617448945`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Estimation", "Subsection",
 CellChangeTimes->{{3.5268174400728083`*^9, 3.526817442680808*^9}}],

Cell["Finding distribution parameters:", "Text",
 CellChangeTimes->{{3.5267675212540216`*^9, 3.526767527953405*^9}, {
  3.5270101493072424`*^9, 3.5270101528775992`*^9}}],

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{"ed", "=", 
   RowBox[{"EstimatedDistribution", "[", 
    RowBox[{"data", ",", 
     RowBox[{"ExampleDistribution", "[", "a", "]"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5267542041958427`*^9, 3.5267542153544807`*^9}, {
   3.526755904636589*^9, 3.526755921474552*^9}, {3.5267559598377466`*^9, 
   3.5267559643810062`*^9}, {3.5267560717131453`*^9, 3.5267561025849113`*^9}, 
   3.5267561717228656`*^9, {3.5267648790998993`*^9, 3.5267648797699375`*^9}, {
   3.5267653333778825`*^9, 3.526765333638897*^9}, {3.5268144528290043`*^9, 
   3.526814455593004*^9}, {3.5268159136340876`*^9, 3.5268159237821026`*^9}, {
   3.5268165015258756`*^9, 3.5268165017719*^9}}],

Cell[BoxData[
 RowBox[{"FindDistributionParameters", "[", 
  RowBox[{"data", ",", 
   RowBox[{"ExampleDistribution", "[", "a", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.526817532305808*^9, 3.5268175395918083`*^9}}],

Cell["Using general framewok:", "Text",
 CellChangeTimes->{{3.5270101638056917`*^9, 3.527010173116623*^9}}],

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{"EstimatedDistribution", "[", 
   RowBox[{"data", ",", 
    RowBox[{"ExampleDistribution", "[", "a", "]"}], ",", 
    RowBox[{"ParameterEstimator", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<MaximumLikelihood\>\"", ",", 
       RowBox[{"Method", "\[Rule]", "\"\<NMaximize\>\""}]}], "}"}]}]}], "]"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.5267542041958427`*^9, 3.5267542153544807`*^9}, {
   3.526755904636589*^9, 3.526755921474552*^9}, {3.5267559598377466`*^9, 
   3.5267559643810062`*^9}, {3.5267560717131453`*^9, 3.5267561025849113`*^9}, 
   3.5267561717228656`*^9, {3.5267648790998993`*^9, 3.5267648797699375`*^9}, {
   3.5267653333778825`*^9, 3.526765333638897*^9}, {3.5268144528290043`*^9, 
   3.526814455593004*^9}, {3.5268146746310043`*^9, 3.526814695358004*^9}, {
   3.526817523718808*^9, 3.526817524746808*^9}}],

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{"EstimatedDistribution", "[", 
   RowBox[{"data", ",", 
    RowBox[{"ExampleDistribution", "[", "a", "]"}], ",", 
    RowBox[{"ParameterEstimator", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<MaximumLikelihood\>\"", ",", 
       RowBox[{"Method", "\[Rule]", "\"\<FindMaximum\>\""}]}], "}"}]}]}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5267542041958427`*^9, 3.5267542153544807`*^9}, {
   3.526755904636589*^9, 3.526755921474552*^9}, {3.5267559598377466`*^9, 
   3.5267559643810062`*^9}, {3.5267560717131453`*^9, 3.5267561025849113`*^9}, 
   3.5267561717228656`*^9, {3.5267648790998993`*^9, 3.5267648797699375`*^9}, {
   3.5267653333778825`*^9, 3.526765333638897*^9}, {3.5268144528290043`*^9, 
   3.526814455593004*^9}, {3.5268146746310043`*^9, 3.526814695358004*^9}, {
   3.526816713682089*^9, 3.526816717203441*^9}, {3.526817526787808*^9, 
   3.526817527287808*^9}}],

Cell["Using method of moments: (we did not define this)", "Text",
 CellChangeTimes->{{3.5270102453878493`*^9, 3.527010272665577*^9}}],

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{"EstimatedDistribution", "[", 
   RowBox[{"data", ",", 
    RowBox[{"ExampleDistribution", "[", "a", "]"}], ",", 
    RowBox[{"ParameterEstimator", "\[Rule]", "\"\<MethodOfMoments\>\""}]}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.527010209777289*^9, 3.5270102174650574`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Hypothesis testing", "Subsection",
 CellChangeTimes->{{3.526817447582808*^9, 3.526817450687808*^9}}],

Cell["Testing whether data could have come from the family:", "Text",
 CellChangeTimes->{{3.526767510856427*^9, 3.526767564456493*^9}}],

Cell[BoxData[
 RowBox[{"DistributionFitTest", "[", 
  RowBox[{"data", ",", 
   RowBox[{"ExampleDistribution", "[", "a", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\"\<TestDataTable\>\"", ",", "\"\<ShortTestConclusion\>\""}], 
    "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5267561950722013`*^9, 3.5267563210464067`*^9}, {
  3.5267648569746337`*^9, 3.526764861387886*^9}, {3.5267652417526417`*^9, 
  3.526765267219098*^9}, {3.5267658304553137`*^9, 3.5267658438930817`*^9}}],

Cell[BoxData[
 RowBox[{"DistributionFitTest", "[", 
  RowBox[{"data", ",", 
   RowBox[{"ExampleDistribution", "[", "2", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\"\<TestDataTable\>\"", ",", "All"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5268174784748077`*^9, 3.526817503781808*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Statistical visualization", "Subsection",
 CellChangeTimes->{{3.526817460118808*^9, 3.526817464627808*^9}}],

Cell["Using statistical visualization:", "Text",
 CellChangeTimes->{{3.526767573118988*^9, 3.5267675833175716`*^9}}],

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"ProbabilityPlot", "[", 
        RowBox[{"data", ",", "ed", ",", 
         RowBox[{"ImageSize", "\[Rule]", "250"}]}], "]"}], ",", 
       "ProbabilityPlot"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"QuantilePlot", "[", 
        RowBox[{"data", ",", "ed", ",", 
         RowBox[{"ImageSize", "\[Rule]", "250"}]}], "]"}], ",", 
       "QuantilePlot"}], "]"}]}], "}"}], ",", 
   RowBox[{"Spacer", "[", "10", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5267561785952587`*^9, 3.526756186494711*^9}, {
  3.5267653280615788`*^9, 3.5267653639046288`*^9}, {3.526765633824067*^9, 
  3.5267657976194353`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Random number generation", "Subsection",
 CellChangeTimes->{{3.5268177767213917`*^9, 3.5268177813878584`*^9}}],

Cell["Use of framework power:", "Text",
 CellChangeTimes->{{3.5267675879188347`*^9, 3.526767600285542*^9}}],

Cell[BoxData[
 RowBox[{"RandomVariate", "[", 
  RowBox[{
   RowBox[{"CopulaDistribution", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<Frank\>\"", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ExampleDistribution", "[", "1.53", "]"}], ",", 
       RowBox[{"ParetoDistribution", "[", 
        RowBox[{"1", ",", "2"}], "]"}]}], "}"}]}], "]"}], ",", "10"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5267649077245364`*^9, 3.526764911856773*^9}, {
  3.52676604614065*^9, 3.526766088183055*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
   "Statistics`Library`BuiltInDistributionHeadQ", "[", "ExampleDistribution", 
    "]"}], "^=", "True"}], ";"}]], "Input",
 CellChangeTimes->{{3.526817802622982*^9, 3.5268178177514944`*^9}, {
  3.526817983515069*^9, 3.5268179926529827`*^9}}],

Cell[BoxData[
 RowBox[{"RandomVariate", "[", 
  RowBox[{"TransformedDistribution", "[", 
   RowBox[{
    RowBox[{"y", " ", "x"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[Distributed]", 
       RowBox[{"ExponentialDistribution", "[", "1", "]"}]}], ",", 
      RowBox[{"y", "\[Distributed]", 
       RowBox[{"ExampleDistribution", "[", "1", "]"}]}]}], "}"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.526767607560958*^9, 3.526767658513872*^9}, 
   3.526767707715687*^9, {3.5267677962217493`*^9, 3.5267678349739656`*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{922, 855},
WindowMargins->{{391, Automatic}, {Automatic, 43}},
ShowSelection->True,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell["Style Environment Names", "Section"], 
      Cell[
       StyleData[All, "Condensed"], MenuSortingValue -> None], 
      Cell[
       StyleData[All, "SlideShow"], DockedCells -> {
         FEPrivate`FrontEndResource["FEExpressions", "SlideshowToolbar"], 
         Cell[
          BoxData[
           GraphicsBox[
            TagBox[
             RasterBox[CompressedData["
1:eJzt3U9oXGe65/HAgEBSIVllV1UQjkEkyGAnYNyy2w43ThzjONyOO3YTbDqI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              "], {{0, 90}, {2400, 0}}, {0, 255}, ColorFunction -> RGBColor], 
             BoxForm`ImageTag[
             "Byte", ColorSpace -> "RGB", Interleaving -> True], Selectable -> 
             False], BaseStyle -> "ImageGraphics", ImageSize -> 
            Magnification[1], ImageSizeRaw -> {2400, 90}, 
            PlotRange -> {{0, 2400}, {0, 90}}]], "", CellMargins -> 0, 
          CellChangeTimes -> {{3.516548605022827*^9, 3.516548633085456*^9}, {
            3.516616961864057*^9, 3.516616982571135*^9}, 
            3.518187891728025*^9, {3.518199033657151*^9, 
            3.5181990340305967`*^9}}]}, CellMargins -> 0, 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.739193, 0.750317, 0.747173]}], 
      Cell[
       BoxData[
        GraphicsBox[
         TagBox[
          RasterBox[CompressedData["
1:eJzt3U9oXGe65/HAgEBSIVllV1UQjkEkyGAnYNyy2w43ThzjONyOO3YTbDqI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           "], {{0, 90}, {2400, 0}}, {0, 255}, ColorFunction -> RGBColor], 
          BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
           Selectable -> False], BaseStyle -> "ImageGraphics", ImageSize -> 
         Magnification[1], ImageSizeRaw -> {2400, 90}, 
         PlotRange -> {{0, 2400}, {0, 90}}]], "", CellMargins -> 0, 
       CellChangeTimes -> {{3.516548605022827*^9, 3.516548633085456*^9}, {
         3.516616961864057*^9, 3.516616982571135*^9}, 3.518187891728025*^9, {
         3.518199033657151*^9, 3.5181990340305967`*^9}}], 
      Cell[
       BoxData[
        RowBox[{
          RowBox[{"(*", 
            
            RowBox[{"Evaluate", " ", "the", " ", "following", " ", "to", " ", 
              "copy", " ", "the", " ", "style", " ", "of", " ", "the", " ", 
              "cell", " ", "above", " ", "into", " ", "\[IndentingNewLine]", 
              "the", " ", "docked", " ", "cell", " ", "style", " ", "of", " ", 
              RowBox[{"the", " ", "'"}], 
              RowBox[{"Notebook", "'"}], " ", "definition", " ", 
              RowBox[{"(", 
                RowBox[{"2", " ", "cells", " ", "above"}], ")"}], " ", 
              "\[IndentingNewLine]", "These", " ", "two", " ", "cell", " ", 
              "can", " ", "be", " ", "removed", " ", "once", " ", "the", " ", 
              "docked", " ", "cell", " ", "is", " ", 
              RowBox[{"created", "."}]}], "\[IndentingNewLine]", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              RowBox[{"SelectionMove", "[", 
                RowBox[{
                  RowBox[{"SelectedNotebook", "[", "]"}], ",", "Previous", 
                  ",", "Cell", ",", "2"}], "]"}], ";"}], 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"celldata", "=", 
                RowBox[{"NotebookRead", "[", 
                  RowBox[{"SelectedNotebook", "[", "]"}], "]"}]}], ";"}], 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"SelectionMove", "[", 
                RowBox[{
                  RowBox[{"SelectedNotebook", "[", "]"}], ",", "Previous", 
                  ",", "Cell", ",", "1"}], "]"}], ";"}], 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"SetOptions", "[", 
                RowBox[{
                  RowBox[{"NotebookSelection", "[", 
                    RowBox[{"SelectedNotebook", "[", "]"}], "]"}], ",", 
                  RowBox[{"DockedCells", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"FEPrivate`FrontEndResource", "[", 
                    
                    RowBox[{
                    "\"FEExpressions\"", ",", "\"SlideshowToolbar\""}], "]"}],
                     ",", "celldata"}], "}"}]}]}], "]"}], ";"}]}]}]], "Input",
        FontWeight -> "Bold"]}, Open]], 
   Cell[
    CellGroupData[{
      Cell["Notebook Options Settings", "Section"], 
      Cell[
       StyleData["Notebook"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.739193, 0.750317, 0.747173]}]}, Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Title and Section Cells", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], ShowCellBracket -> Automatic, ShowGroupOpener -> 
          False, CellMargins -> {{48, 0}, {30, 0}}, 
          CellBracketOptions -> {"Margins" -> {0, 0}}, 
          CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> False, 
          CellFrameMargins -> {{20, 20}, {20, 20}}, DefaultNewInlineCellStyle -> 
          "None", InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, 
          CellChangeTimes -> {3.479211616867702*^9, 3.483202458952606*^9}, 
          TextAlignment -> Left, LineSpacing -> {1, 0}, LanguageCategory -> 
          "NaturalLanguage", CounterIncrements -> "Title", 
          CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
            "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontFamily -> 
          "Helvetica", FontSize -> 48, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> "Plain", 
          FontVariations -> {
           "Masked" -> False, "Outline" -> False, "Shadow" -> False, 
            "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
          RGBColor[
           0.8156862745098039, 0.07058823529411765, 0.07058823529411765], 
          Background -> None], 
         Cell[
          StyleData["Title", "Presentation", StyleDefinitions -> None], 
          CellMargins -> {{55, 3}, {14, 125}}, LineSpacing -> {1, 5}, 
          FontSize -> 28], 
         Cell[
          StyleData[
          "Title", "SlideShow", StyleDefinitions -> 
           StyleData["Title", "Presentation"]], 
          CellMargins -> {{55, 3}, {14, 35}}, FontSize -> 55], 
         Cell[
          StyleData["Title", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{2, 0}, {0, 10}}, LineSpacing -> {1, 18}, FontSize -> 
          15]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subtitle"], ShowCellBracket -> False, 
          CellMargins -> {{58, 0}, {0, 5}}, 
          CellBracketOptions -> {"Margins" -> {0, 0}}, 
          CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> False,
           DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, TextAlignment -> Left, LanguageCategory -> 
          "NaturalLanguage", CounterIncrements -> "Subtitle", 
          CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
            "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
          FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> 
          RGBColor[
           0.34901960784313724`, 0.5254901960784314, 0.5176470588235295], 
          Background -> None], 
         Cell[
          StyleData["Subtitle", "Presentation", StyleDefinitions -> None], 
          CellMargins -> {{58, 0}, {0, 5}}, FontSize -> 20], 
         Cell[
          StyleData[
          "Subtitle", "SlideShow", StyleDefinitions -> 
           StyleData["Subtitle", "Presentation"]]], 
         Cell[
          StyleData["Subtitle", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{2, 0}, {0, 5}}, FontSize -> 14, Background -> 
          GrayLevel[1]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubtitle", StyleDefinitions -> StyleData["Subtitle"]],
           FontSize -> Inherited + 3], 
         Cell[
          StyleData["Subsubtitle", "Presentation"], FontSize -> 
          Inherited + 3], 
         Cell[
          StyleData[
          "Subsubtitle", "SlideShow", StyleDefinitions -> 
           StyleData["Subsubtitle", "Presentation"]]], 
         Cell[
          StyleData["Subsubtitle", "Printout"], FontSize -> Inherited + 0]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0.2, 0}}, 
          ShowGroupOpener -> False, CellMargins -> {{50, 50}, {10, 25}}, 
          FontSize -> 36, FontWeight -> "Plain", FontColor -> 
          RGBColor[
           0.8156862745098039, 0.07058823529411765, 0.07058823529411765]], 
         Cell[
          StyleData["Section", "Presentation"], 
          CellFrame -> {{0, 0}, {0.2, 0}}, 
          CellMargins -> {{58, 50}, {10, 35}}], 
         Cell[
          StyleData[
          "Section", "SlideShow", StyleDefinitions -> 
           StyleData["Section", "Presentation"]], 
          CellMargins -> {{58, 50}, {10, 35}}], 
         Cell[
          StyleData["Section", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {7, 22}}, FontSize -> 14]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellDingbat -> None, ShowGroupOpener -> 
          True, CellMargins -> {{65, Inherited}, {0, 12}}, 
          CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
          False, DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, LanguageCategory -> "NaturalLanguage", 
          CounterIncrements -> "Subsection", 
          CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
          "Helvetica", FontSize -> 24, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> 
          RGBColor[
           0.34901960784313724`, 0.5254901960784314, 0.5176470588235295]], 
         Cell[
          StyleData["Subsection", "Presentation"], 
          CellMargins -> {{60, 50}, {6, 15}}, LineSpacing -> {1, 0}, 
          FontFamily -> "Helvetica"], 
         Cell[
          StyleData["Subsection", "SlideShow"], 
          CellMargins -> {{60, 50}, {8, 12}}, LineSpacing -> {1, 0}, 
          FontFamily -> "Helvetica"], 
         Cell[
          StyleData["Subsection", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {2, 22}}, FontSize -> 12]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], CellDingbat -> None, ShowGroupOpener -> 
          True, CellMargins -> {{80, Inherited}, {0, 12}}, 
          CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
          False, DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, LanguageCategory -> "NaturalLanguage", 
          CounterIncrements -> "Subsubsection", FontFamily -> "Helvetica", 
          FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> RGBColor[0.279216, 0.420392, 0.414118]], 
         Cell[
          StyleData["Subsubsection", "Presentation"], 
          CellMargins -> {{60, 50}, {6, 20}}, LineSpacing -> {1, 0}], 
         Cell[
          StyleData[
          "Subsubsection", "SlideShow", StyleDefinitions -> 
           StyleData["Subsubsection", "Presentation"]]], 
         Cell[
          StyleData["Subsubsection", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {2, 22}}, FontSize -> 11]}, Open]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Body Text", "Section"], 
      Cell[
       CellGroupData[{
         Cell["Standard", "Subsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{60, 10}, {7, 7}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 3}, CounterIncrements -> "Text",
              FontFamily -> "Helvetica", FontSize -> 17], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{60, 50}, {10, 10}}, FontSize -> 17], 
            Cell[
             StyleData[
             "Text", "SlideShow", StyleDefinitions -> 
              StyleData["Text", "Presentation"]]], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{2, 2}, {6, 6}}, 
             TextJustification -> 0.5, Hyphenation -> True, FontSize -> 10]}, 
           Open]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Display", "Subsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> 
             Cell["\[FilledSmallCircle]", FontWeight -> "Bold"], 
             CellMargins -> {{84, 10}, {7, 7}}, ReturnCreatesNewCell -> True, 
             CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
             CounterIncrements -> "Item"], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{124, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "Item", "SlideShow", StyleDefinitions -> 
              StyleData["Item", "Presentation"]]], 
            Cell[
             StyleData["Item", "Printout"], CellMargins -> {{2, 2}, {0, 6}}]},
            Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem", StyleDefinitions -> StyleData["Item"]], 
             CellMargins -> {{108, 10}, {7, 7}}, ReturnCreatesNewCell -> True,
              CellGroupingRules -> {"GroupTogetherNestedGrouping", 15150}, 
             CounterIncrements -> "Subitem"], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{146, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "Subitem", "SlideShow", StyleDefinitions -> 
              StyleData["Subitem", "Presentation"]]], 
            Cell[
             StyleData["Subitem", "Printout"], 
             CellMargins -> {{30, 2}, {0, 6}}]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered", StyleDefinitions -> StyleData["Text"]],
              CellDingbat -> Cell[
               TextData[{
                 CounterBox["ItemNumbered"], "."}]], 
             CellMargins -> {{84, 10}, {7, 7}}, ReturnCreatesNewCell -> True, 
             CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
             CounterIncrements -> "ItemNumbered"], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{124, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "ItemNumbered", "SlideShow", StyleDefinitions -> 
              StyleData["ItemNumbered", "Presentation"]]], 
            Cell[
             StyleData["ItemNumbered", "Printout"], 
             CellMargins -> {{2, 2}, {0, 6}}]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "SubitemNumbered", StyleDefinitions -> 
              StyleData["ItemNumbered"]], CellDingbat -> Cell[
               TextData[{
                 CounterBox["SubitemNumbered", CounterFunction :> (Part[
                    CharacterRange["a", "z"], #]& )], "."}]], 
             CellMargins -> {{108, 10}, {7, 7}}, ReturnCreatesNewCell -> True,
              CellGroupingRules -> {"GroupTogetherNestedGrouping", 15150}, 
             CounterIncrements -> "SubitemNumbered"], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{146, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "SubitemNumbered", "SlideShow", StyleDefinitions -> 
              StyleData["SubitemNumbered", "Presentation"]]], 
            Cell[
             StyleData["SubitemNumbered", "Printout"], 
             CellMargins -> {{30, 2}, {0, 6}}]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "ItemParagraph", StyleDefinitions -> StyleData["Item"]], 
             CellDingbat -> None, CellMargins -> {{84, 10}, {7, 7}}, 
             ReturnCreatesNewCell -> True, 
             CellGroupingRules -> {"GroupTogetherNestedGrouping", 15100}, 
             CounterIncrements -> "ItemParagraph"], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{124, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "ItemParagraph", "SlideShow", StyleDefinitions -> 
              StyleData["ItemParagraph", "Presentation"]]], 
            Cell[
             StyleData["ItemParagraph", "Printout"], 
             CellMargins -> {{14, 2}, {0, 6}}]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "SubitemParagraph", StyleDefinitions -> StyleData["Subitem"]], 
             CellDingbat -> None, ReturnCreatesNewCell -> True, 
             CellGroupingRules -> {"GroupTogetherNestedGrouping", 15200}, 
             CounterIncrements -> "SubitemParagraph"], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"]], 
            Cell[
             StyleData[
             "SubitemParagraph", "SlideShow", StyleDefinitions -> 
              StyleData["SubitemParagraph", "Presentation"]]], 
            Cell[
             StyleData["SubitemParagraph", "Printout"]]}, Open]]}, Open]]}, 
     Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Formulas and Programming", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"]], 
         Cell[
          StyleData["DisplayFormula", "Presentation"], 
          CellMargins -> {{60, Inherited}, {Inherited 1.5, Inherited 1.5}}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "DisplayFormula", "SlideShow", StyleDefinitions -> 
           StyleData["DisplayFormula", "Presentation"]]], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, FontSize -> 
          10]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}]]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered"], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Presentation"], 
          CellMargins -> {{60, Inherited}, {Inherited 1.5, Inherited 1.5}}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "DisplayFormulaNumbered", "SlideShow", StyleDefinitions -> 
           StyleData["DisplayFormulaNumbered", "Presentation"]]], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{39, Inherited}, {Inherited, Inherited}}]}, Open]]},
      Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Inline Formatting", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InlineFormula"]], 
         Cell[
          StyleData["InlineFormula", "Presentation"], FontSize -> 17], 
         Cell[
          StyleData[
          "InlineFormula", "SlideShow", StyleDefinitions -> 
           StyleData["InlineFormula", "Presentation"]]], 
         Cell[
          StyleData["InlineFormula", "Printout"]]}, Open]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Input and Output Cells", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], ShowCellBracket -> True, 
          CellMargins -> {{103, 10}, {5, 7}}, 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.734936, 0.713848, 0.694041]}, Evaluatable -> 
          True, CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
          True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
          DefaultFormatType -> DefaultInputFormatType, 
          "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
          FormatType -> InputForm, ShowStringCharacters -> True, NumberMarks -> 
          True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, 
          CounterIncrements -> "Input", FontWeight -> "Bold"], 
         Cell[
          StyleData["Input", "Presentation"], 
          CellMargins -> {{110, 50}, {8, 10}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "Input", "SlideShow", StyleDefinitions -> 
           StyleData["Input", "Presentation"]]], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{39, 0}, {4, 6}}, 
          LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], ShowCellBracket -> True, 
          CellMargins -> {{103, 10}, {7, 7}}, 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.734936, 0.713848, 0.694041]}, Evaluatable -> 
          True, CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
          True, DefaultFormatType -> DefaultInputFormatType, 
          "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
          FormatType -> InputForm, ShowStringCharacters -> True, NumberMarks -> 
          True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, 
          CounterIncrements -> "Input", MenuSortingValue -> 1550, FontWeight -> 
          "Bold"], 
         Cell[
          StyleData["InputOnly", "Presentation"], 
          CellMargins -> {{110, Inherited}, {8, 10}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "InputOnly", "SlideShow", StyleDefinitions -> 
           StyleData["InputOnly", "Presentation"]]], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{39, 0}, {4, 6}}, 
          LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], ShowCellBracket -> True, 
          CellMargins -> {{103, 10}, {7, 5}}, 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.734936, 0.713848, 0.694041]}, 
          CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping", 
          CellHorizontalScrolling -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, DefaultFormatType -> 
          DefaultOutputFormatType, "TwoByteSyntaxCharacterAutoReplacement" -> 
          True, HyphenationOptions -> {
           "HyphenationCharacter" -> "\[Continuation]"}, 
          AutoItalicWords -> {}, LanguageCategory -> None, FormatType -> 
          InputForm, CounterIncrements -> "Output"], 
         Cell[
          StyleData["Output", "Presentation"], 
          CellMargins -> {{110, 50}, {10, 8}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "Output", "SlideShow", StyleDefinitions -> 
           StyleData["Output", "Presentation"]]], 
         Cell[
          StyleData["Output", "Printout"], CellMargins -> {{39, 0}, {6, 4}}, 
          FontSize -> 9]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Code"], CellMargins -> {{103, 10}, {5, 10}}], 
         Cell[
          StyleData["Code", "Presentation"], 
          CellMargins -> {{110, 50}, {8, 10}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "Code", "SlideShow", StyleDefinitions -> 
           StyleData["Code", "Presentation"]]], 
         Cell[
          StyleData["Code", "Printout"], CellMargins -> {{39, 0}, {4, 6}}, 
          LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], 
          CellMargins -> {{103, Inherited}, {Inherited, Inherited}}, FontSize -> 
          14], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{70, Inherited}, {Inherited 1.5, Inherited 1.5}}, 
          FontSize -> 17, Magnification -> Inherited 1.5], 
         Cell[
          StyleData[
          "Print", "SlideShow", StyleDefinitions -> 
           StyleData["Print", "Presentation"]]], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{39, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "WolframAlphaShortInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{98, 10}, {5, 7}}, EvaluationMode -> 
          "WolframAlphaShort", 
          CellEventActions -> {"ReturnKeyDown" :> FrontEndTokenExecute[
              EvaluationNotebook[], "HandleShiftReturn"]}, 
          CellFrameLabels -> {{
             Cell[
              BoxData[
               DynamicBox[
                FEPrivate`FrontEndResource["WABitmaps", "Equal"]]], 
              CellBaseline -> Baseline], None}, {None, None}}, FormatType -> 
          TextForm, FontFamily -> "Helvetica"], 
         Cell[
          StyleData["WolframAlphaShortInput", "Presentation"], 
          CellMargins -> {{107, 50}, {8, 10}}], 
         Cell[
          StyleData[
          "WolframAlphaShortInput", "SlideShow", StyleDefinitions -> 
           StyleData["WolframAlphaShortInput", "Presentation"]]], 
         Cell[
          StyleData["WolframAlphaShortInput", "Printout"], 
          CellFrameLabelMargins -> 3]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "WolframAlphaLong", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{100, 10}, {5, 7}}, 
          StyleKeyMapping -> {
           "=" -> "Input", "Backspace" -> "WolframAlphaShort"}, 
          EvaluationMode -> "WolframAlphaLong", 
          CellEventActions -> {"ReturnKeyDown" :> FrontEndTokenExecute[
              EvaluationNotebook[], "HandleShiftReturn"]}, 
          CellFrameLabels -> {{
             Cell[
              BoxData[
               DynamicBox[
                FEPrivate`FrontEndResource["WABitmaps", "SpikeyEqual"]]]], 
             None}, {None, None}}, DefaultFormatType -> TextForm, FormatType -> 
          TextForm, FontFamily -> "Helvetica"], 
         Cell[
          StyleData["WolframAlphaLong", "Presentation"], 
          CellMargins -> {{107, 50}, {8, 10}}], 
         Cell[
          StyleData[
          "WolframAlphaLong", "SlideShow", StyleDefinitions -> 
           StyleData["WolframAlphaLong", "Presentation"]], 
          CellMargins -> {{107, 50}, {8, 10}}], 
         Cell[
          StyleData["WolframAlphaLong", "Printout"], CellFrameLabelMargins -> 
          3]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Program"], CellMargins -> {{60, 4}, {6, 8}}], 
         Cell[
          StyleData["Program", "Presentation"], 
          CellMargins -> {{60, 50}, {8, 10}}, LineSpacing -> {1, 0}, FontSize -> 
          17], 
         Cell[
          StyleData[
          "Program", "SlideShow", StyleDefinitions -> 
           StyleData["Program", "Presentation"]]], 
         Cell[
          StyleData["Program", "Printout"], FontSize -> 9]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"]], 
         Cell[
          StyleData["CellLabel", "Presentation"], FontSize -> 12], 
         Cell[
          StyleData[
          "CellLabel", "SlideShow", StyleDefinitions -> 
           StyleData["CellLabel", "Presentation"]]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ManipulateLabel"]], 
         Cell[
          StyleData["ManipulateLabel", "Presentation"], FontSize -> 15], 
         Cell[
          StyleData[
          "ManipulateLabel", "SlideShow", StyleDefinitions -> 
           StyleData["ManipulateLabel", "Presentation"]]], 
         Cell[
          StyleData["ManipulateLabel", "Printout"], FontSize -> 8]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GraphicsLabel"]], 
         Cell[
          StyleData["GraphicsLabel", "Presentation"], FontSize -> 14], 
         Cell[
          StyleData[
          "GraphicsLabel", "SlideShow", StyleDefinitions -> 
           StyleData["GraphicsLabel", "Presentation"]]], 
         Cell[
          StyleData["GraphicsLabel", "Printout"], FontSize -> 8]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Graphics3DLabel"]], 
         Cell[
          StyleData["Graphics3DLabel", "Presentation"], FontSize -> 14], 
         Cell[
          StyleData[
          "Graphics3DLabel", "SlideShow", StyleDefinitions -> 
           StyleData["Graphics3DLabel", "Presentation"]]], 
         Cell[
          StyleData["Graphics3DLabel", "Printout"], FontSize -> 8]}, Open]]}, 
     Open]], 
   Cell[
    CellGroupData[{
      Cell[
      "Styles for SlideShow", "Section", 
       CellChangeTimes -> {{3.514665148412793*^9, 3.5146651505550737`*^9}}], 
      Cell[
       StyleData["slideshowheader"], ShowCellBracket -> False, 
       CellMargins -> {{0, 0}, {0, -2}}, Evaluatable -> False, 
       CellHorizontalScrolling -> False, PageBreakBelow -> False, 
       CellFrameMargins -> 0, ImageMargins -> {{0, 0}, {0, 0}}, 
       ImageRegion -> {{0, 1}, {0, 1}}, Magnification -> 1, Background -> 
       GrayLevel[1], CellPadding -> 0, CellFramePadding -> 0], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["hidefromslideshowgraphic"], ShowCellBracket -> False, 
          CellMargins -> {{0, 0}, {0, 0}}, Evaluatable -> False, 
          CellHorizontalScrolling -> False, PageBreakBelow -> False, 
          CellFrameMargins -> 0, ImageMargins -> {{0, 0}, {0, 0}}, 
          ImageRegion -> {{0, 1}, {0, 1}}, Magnification -> 1, Background -> 
          GrayLevel[1], CellPadding -> 0], 
         Cell[
          StyleData["hidefromslideshowgraphic", "SlideShow"], ShowCellBracket -> 
          False, CellElementSpacings -> {
           "CellMinHeight" -> 0, "ClosedCellHeight" -> 0, 
            "ClosedGroupTopMargin" -> 0}, CellOpen -> False, 
          CellHorizontalScrolling -> False]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["slideshowheader2"], ShowCellBracket -> False, 
          CellMargins -> {{0, 0}, {0, 0}}, Evaluatable -> False, 
          CellHorizontalScrolling -> False, PageBreakBelow -> False, 
          ImageMargins -> {{0, 0}, {0, 0}}, ImageRegion -> {{0, 1}, {0, 1}}, 
          Magnification -> 1, Background -> GrayLevel[1]], 
         Cell[
          StyleData["ConferenceGraphicCell", "SlideShow"], ShowCellBracket -> 
          False, CellElementSpacings -> {
           "CellMinHeight" -> 0, "ClosedCellHeight" -> 0, 
            "ClosedGroupTopMargin" -> 0}, CellOpen -> False, 
          CellHorizontalScrolling -> True], 
         Cell[
          StyleData["slideshowheader", "Printout"], FontSize -> 8, 
          Magnification -> 0.75]}, Open]], 
      Cell[
       StyleData[
       "ConferenceGraphicCellSlideShowOnly", StyleDefinitions -> 
        StyleData["ConferenceCellGraphic"]], ShowCellBracket -> False, 
       CellMargins -> 0, 
       CellElementSpacings -> {
        "CellMinHeight" -> 0, "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 
         0}, CellOpen -> False], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SlideShowNavigationBar"], Editable -> True, Selectable -> 
          False, CellFrame -> 0, ShowGroupOpener -> False, 
          CellMargins -> {{0, 0}, {3, 3}}, CellOpen -> True, CellFrameMargins -> 
          0, CellFrameColor -> None, Background -> None], 
         Cell[
          StyleData["SlideShowNavigationBar", "Printout"], PageBreakAbove -> 
          Automatic]}, Open]]}, Open]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Microsoft Windows (64-bit) (February 23, 2011)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 222, 3, 85, "Title"],
Cell[804, 27, 132, 1, 22, "Subsubtitle"],
Cell[939, 30, 473, 10, 78, "Text"],
Cell[1415, 42, 163, 3, 33, "Text"],
Cell[1581, 47, 824, 23, 43, "DisplayFormula"],
Cell[2408, 72, 199, 5, 33, "Text"],
Cell[CellGroupData[{
Cell[2632, 81, 136, 1, 80, "Section"],
Cell[CellGroupData[{
Cell[2793, 86, 100, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2918, 91, 106, 1, 35, "Subsubsection"],
Cell[3027, 94, 302, 9, 40, "DisplayFormula"],
Cell[3332, 105, 646, 21, 47, "Input"],
Cell[3981, 128, 544, 18, 47, "Input"],
Cell[4528, 148, 97, 1, 33, "Text"],
Cell[4628, 151, 575, 15, 56, "DisplayFormula"]
}, Closed]],
Cell[CellGroupData[{
Cell[5240, 171, 99, 1, 27, "Subsubsection"],
Cell[5342, 174, 411, 13, 26, "DisplayFormula"],
Cell[5756, 189, 889, 28, 47, "Input"],
Cell[6648, 219, 565, 19, 47, "Input"],
Cell[7216, 240, 121, 2, 33, "Text"],
Cell[7340, 244, 657, 17, 42, "DisplayFormula"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[8046, 267, 95, 1, 31, "Subsection"],
Cell[8144, 270, 325, 11, 36, "Text"],
Cell[CellGroupData[{
Cell[8494, 285, 1144, 31, 80, "Input"],
Cell[9641, 318, 664, 20, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10342, 343, 567, 17, 44, "Input"],
Cell[10912, 362, 73, 1, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[11034, 369, 95, 1, 31, "Subsection"],
Cell[11132, 372, 185, 4, 33, "Text"],
Cell[CellGroupData[{
Cell[11342, 380, 1076, 31, 47, "Input"],
Cell[12421, 413, 431, 11, 45, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12913, 431, 99, 1, 80, "Section"],
Cell[CellGroupData[{
Cell[13037, 436, 107, 1, 39, "Subsection"],
Cell[13147, 439, 268, 5, 28, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[13452, 449, 100, 1, 31, "Subsection"],
Cell[13555, 452, 499, 10, 49, "Input",
 InitializationCell->True],
Cell[14057, 464, 905, 20, 109, "Input",
 InitializationCell->True],
Cell[14965, 486, 834, 18, 89, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[15836, 509, 112, 1, 31, "Subsection"],
Cell[15951, 512, 408, 10, 49, "Input",
 InitializationCell->True],
Cell[16362, 524, 1363, 40, 68, "Input",
 InitializationCell->True],
Cell[17728, 566, 2597, 68, 128, "Input",
 InitializationCell->True],
Cell[20328, 636, 2716, 70, 128, "Input",
 InitializationCell->True],
Cell[23047, 708, 3609, 95, 226, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[26693, 808, 97, 1, 31, "Subsection"],
Cell[CellGroupData[{
Cell[26815, 813, 101, 1, 35, "Subsubsection"],
Cell[26919, 816, 418, 12, 43, "Text"],
Cell[CellGroupData[{
Cell[27362, 832, 221, 5, 28, "Input"],
Cell[27586, 839, 1763, 50, 53, "Output"]
}, Open  ]],
Cell[29364, 892, 135, 2, 33, "Text"],
Cell[CellGroupData[{
Cell[29524, 898, 688, 22, 47, "Input",
 Evaluatable->False],
Cell[30215, 922, 270, 7, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30522, 934, 992, 31, 47, "Input"],
Cell[31517, 967, 165, 2, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[31731, 975, 108, 1, 27, "Subsubsection"],
Cell[31842, 978, 845, 23, 73, "Input",
 InitializationCell->True],
Cell[32690, 1003, 591, 14, 72, "Input",
 InitializationCell->True],
Cell[33284, 1019, 593, 14, 72, "Input",
 InitializationCell->True],
Cell[33880, 1035, 581, 14, 52, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[34498, 1054, 106, 1, 27, "Subsubsection"],
Cell[34607, 1057, 626, 18, 66, "Input",
 InitializationCell->True],
Cell[35236, 1077, 711, 21, 67, "Input",
 InitializationCell->True],
Cell[35950, 1100, 802, 23, 67, "Input",
 InitializationCell->True],
Cell[36755, 1125, 971, 28, 106, "Input",
 InitializationCell->True],
Cell[37729, 1155, 1254, 35, 87, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[39032, 1196, 108, 1, 31, "Subsection"],
Cell[39143, 1199, 216, 4, 55, "Text"],
Cell[39362, 1205, 250, 7, 34, "Text"],
Cell[CellGroupData[{
Cell[39637, 1216, 219, 6, 35, "Subsubsection"],
Cell[39859, 1224, 199, 4, 33, "Text"],
Cell[CellGroupData[{
Cell[40083, 1232, 370, 9, 28, "Input"],
Cell[40456, 1243, 453, 12, 44, "Output"]
}, Open  ]],
Cell[40924, 1258, 188, 2, 33, "Text"],
Cell[41115, 1262, 1488, 45, 101, "Input",
 InitializationCell->True],
Cell[42606, 1309, 142, 1, 33, "Text"],
Cell[CellGroupData[{
Cell[42773, 1314, 1477, 44, 80, "Input"],
Cell[44253, 1360, 8948, 152, 238, "Output"]
}, Open  ]],
Cell[53216, 1515, 237, 7, 33, "Text"],
Cell[CellGroupData[{
Cell[53478, 1526, 677, 19, 49, "Input"],
Cell[54158, 1547, 1186, 33, 48, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[55393, 1586, 153, 2, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[55571, 1592, 1046, 32, 44, "Input",
 Evaluatable->False],
Cell[56620, 1626, 721, 21, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57378, 1652, 156, 3, 28, "Input",
 Evaluatable->False],
Cell[57537, 1657, 262, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57836, 1668, 755, 20, 30, "Input",
 Evaluatable->False],
Cell[58594, 1690, 704, 20, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59335, 1715, 757, 20, 30, "Input",
 Evaluatable->False],
Cell[60095, 1737, 602, 18, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60734, 1760, 1088, 35, 54, "Input",
 Evaluatable->False],
Cell[61825, 1797, 145, 3, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62007, 1805, 2157, 62, 181, "Input",
 Evaluatable->False],
Cell[64167, 1869, 1675, 53, 65, "Output"]
}, Open  ]],
Cell[65857, 1925, 2986, 98, 97, "DisplayFormula"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[68892, 2029, 146, 1, 31, "Subsection"],
Cell[69041, 2032, 333, 8, 28, "Input",
 InitializationCell->True],
Cell[69377, 2042, 239, 5, 28, "Input",
 InitializationCell->True],
Cell[69619, 2049, 248, 10, 158, "Program"],
Cell[69870, 2061, 4752, 128, 237, "Input",
 InitializationCell->True],
Cell[74625, 2191, 5813, 154, 339, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[80475, 2350, 113, 1, 31, "Subsection"],
Cell[CellGroupData[{
Cell[80613, 2355, 163, 2, 35, "Subsubsection"],
Cell[80779, 2359, 354, 11, 33, "Text"],
Cell[81136, 2372, 771, 20, 98, "Input"],
Cell[81910, 2394, 162, 2, 33, "Text"],
Cell[82075, 2398, 499, 13, 28, "Input"],
Cell[82577, 2413, 110, 1, 33, "Text"],
Cell[CellGroupData[{
Cell[82712, 2418, 860, 27, 49, "Input"],
Cell[83575, 2447, 1191, 36, 91, "Output"]
}, Open  ]],
Cell[84781, 2486, 298, 9, 47, "Program"],
Cell[85082, 2497, 173, 2, 33, "Text"],
Cell[CellGroupData[{
Cell[85280, 2503, 385, 11, 28, "Input"],
Cell[85668, 2516, 1958, 58, 81, "Output"]
}, Open  ]],
Cell[87641, 2577, 537, 12, 28, "Input"],
Cell[88181, 2591, 497, 12, 28, "Input"],
Cell[88681, 2605, 213, 4, 28, "Input"],
Cell[88897, 2611, 683, 14, 44, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[89617, 2630, 157, 3, 27, "Subsubsection"],
Cell[89777, 2635, 394, 8, 78, "Program"],
Cell[90174, 2645, 16, 0, 33, "Text"],
Cell[90193, 2647, 1748, 48, 143, "Input"],
Cell[91944, 2697, 138, 1, 33, "Text"],
Cell[92085, 2700, 1906, 52, 221, "Input"],
Cell[CellGroupData[{
Cell[94016, 2756, 328, 8, 28, "Input"],
Cell[94347, 2766, 170, 3, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94554, 2774, 796, 22, 69, "Input"],
Cell[95353, 2798, 12004, 177, 240, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[107406, 2981, 116, 1, 27, "Subsubsection"],
Cell[107525, 2984, 191, 2, 29, "Text"],
Cell[107719, 2988, 591, 15, 52, "Input"],
Cell[108313, 3005, 318, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[108656, 3017, 601, 14, 31, "Input"],
Cell[109260, 3033, 804, 22, 47, "Output"]
}, Open  ]],
Cell[110079, 3058, 336, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[110440, 3070, 531, 11, 31, "Input"],
Cell[110974, 3083, 1363, 40, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112374, 3128, 230, 5, 31, "Input"],
Cell[112607, 3135, 75, 1, 30, "Output"]
}, Open  ]],
Cell[112697, 3139, 106, 1, 29, "Text"],
Cell[112806, 3142, 645, 17, 66, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[113488, 3164, 110, 1, 27, "Subsubsection"],
Cell[113601, 3167, 242, 6, 31, "Input"],
Cell[113846, 3175, 1267, 30, 112, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[115162, 3211, 168, 2, 31, "Subsection"],
Cell[115333, 3215, 1744, 45, 102, "Input",
 InitializationCell->True],
Cell[117080, 3262, 1746, 45, 102, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[118863, 3312, 112, 1, 31, "Subsection"],
Cell[CellGroupData[{
Cell[119000, 3317, 173, 2, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[119198, 3323, 671, 19, 41, "Input"],
Cell[119872, 3344, 519, 16, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120428, 3365, 759, 24, 61, "Input"],
Cell[121190, 3391, 553, 18, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121780, 3414, 312, 7, 41, "Input"],
Cell[122095, 3423, 283, 9, 68, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[122427, 3438, 97, 1, 21, "Subsubsection"],
Cell[122527, 3441, 169, 3, 29, "Text"],
Cell[122699, 3446, 624, 16, 62, "Input",
 InitializationCell->True],
Cell[123326, 3464, 399, 7, 29, "Text"],
Cell[123728, 3473, 350, 7, 62, "Input",
 InitializationCell->True],
Cell[124081, 3482, 296, 7, 65, "Text"],
Cell[124380, 3491, 5173, 130, 399, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[129614, 3628, 198, 3, 80, "Section"],
Cell[CellGroupData[{
Cell[129837, 3635, 110, 1, 39, "Subsection"],
Cell[129950, 3638, 1566, 36, 49, "Input"],
Cell[CellGroupData[{
Cell[131541, 3678, 115, 1, 35, "Subsubsection"],
Cell[131659, 3681, 169, 3, 29, "Text"],
Cell[131831, 3686, 2366, 73, 191, "DisplayFormula"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[134246, 3765, 100, 1, 31, "Subsection"],
Cell[134349, 3768, 169, 2, 33, "Text"],
Cell[134521, 3772, 726, 13, 28, "Input"],
Cell[135250, 3787, 220, 4, 28, "Input"],
Cell[135473, 3793, 107, 1, 33, "Text"],
Cell[135583, 3796, 887, 16, 49, "Input"],
Cell[136473, 3814, 940, 17, 49, "Input"],
Cell[137416, 3833, 133, 1, 33, "Text"],
Cell[137552, 3836, 342, 7, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[137931, 3848, 106, 1, 31, "Subsection"],
Cell[138040, 3851, 135, 1, 29, "Text"],
Cell[138178, 3854, 477, 9, 41, "Input"],
Cell[138658, 3865, 294, 6, 41, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[138989, 3876, 113, 1, 31, "Subsection"],
Cell[139105, 3879, 116, 1, 29, "Text"],
Cell[139224, 3882, 796, 20, 62, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[140057, 3907, 116, 1, 31, "Subsection"],
Cell[140176, 3910, 107, 1, 29, "Text"],
Cell[140286, 3913, 531, 14, 62, "Input"],
Cell[140820, 3929, 288, 7, 41, "Input"],
Cell[141111, 3938, 547, 13, 41, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
