(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     91916,       2124]
NotebookOptionsPosition[     23521,        711]
NotebookOutlinePosition[     89158,       2031]
CellTagsIndexPosition[     89115,       2028]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Creating a truncated distribution\
\>", "Title",
 CellChangeTimes->{{3.526921692667532*^9, 3.5269217084145317`*^9}, {
  3.5280402964227667`*^9, 3.5280402966797667`*^9}}],

Cell["\<\
by Oleksandr Pavlyk, Wolfram Research\
\>", "Subsubtitle",
 CellChangeTimes->{{3.526921716495532*^9, 3.526921725516532*^9}}],

Cell[CellGroupData[{

Cell["Object to be created", "Section",
 CellChangeTimes->{{3.5269217325575323`*^9, 3.526921739351532*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TruncatedNormalDistribution", "[", "r", "]"}], "==", 
  RowBox[{"TruncatedDistribution", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r", ",", "Infinity"}], "}"}], ",", 
    RowBox[{"NormalDistribution", "[", "]"}]}], "]"}]}]], "DisplayFormula",
 CellChangeTimes->{{3.526921741957532*^9, 3.526921810877532*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mostly happy with built\[Hyphen]in", "Section",
 CellChangeTimes->{{3.5269218709995317`*^9, 3.526921888646532*^9}}],

Cell[CellGroupData[{

Cell["Expectations", "Subsection",
 CellChangeTimes->{{3.526922067513318*^9, 3.526922070197586*^9}, 
   3.527264704235261*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mean", "[", 
  RowBox[{"TruncatedDistribution", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Infinity]"}], "}"}], ",", 
    RowBox[{"NormalDistribution", "[", "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5269226729868593`*^9, 3.5269226734199023`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["r", "2"], "2"]}]], " ", 
   SqrtBox[
    FractionBox["2", "\[Pi]"]]}], 
  RowBox[{"Erfc", "[", 
   FractionBox["r", 
    SqrtBox["2"]], "]"}]]], "Output",
 CellChangeTimes->{3.526922673816942*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Variance", "[", 
  RowBox[{"TruncatedDistribution", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Infinity]"}], "}"}], ",", 
    RowBox[{"NormalDistribution", "[", "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.526922127382304*^9, 3.5269221296885347`*^9}, {
  3.5269226510426645`*^9, 3.526922652534814*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     SuperscriptBox["r", "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        SuperscriptBox["r", "2"], "2"]], " ", 
      SqrtBox[
       RowBox[{"2", " ", "\[Pi]"}]], " ", "r", " ", 
      RowBox[{"Erfc", "[", 
       FractionBox["r", 
        SqrtBox["2"]], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       SuperscriptBox["r", "2"]], " ", "\[Pi]", " ", 
      SuperscriptBox[
       RowBox[{"Erfc", "[", 
        FractionBox["r", 
         SqrtBox["2"]], "]"}], "2"]}]}], ")"}]}], 
  RowBox[{"\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"Erfc", "[", 
     FractionBox["r", 
      SqrtBox["2"]], "]"}], "2"]}]]], "Output",
 CellChangeTimes->{3.526922136492215*^9, 3.526922655360097*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Median", "[", 
  RowBox[{"TruncatedDistribution", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Infinity]"}], "}"}], ",", 
    RowBox[{"NormalDistribution", "[", "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5269220755711236`*^9, 3.526922089107477*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SqrtBox["2"]}], " ", 
  RowBox[{"InverseErfc", "[", 
   RowBox[{"1", "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"Erfc", "[", 
      RowBox[{"-", 
       FractionBox["r", 
        SqrtBox["2"]]}], "]"}]}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.526922083987965*^9, 3.526922089527519*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Estimation", "Subsection",
 CellChangeTimes->{{3.5269220631698837`*^9, 3.5269220654331098`*^9}, 
   3.527264710674629*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"{", 
    RowBox[{
    "4.134487644614872`", ",", "4.005023600783223`", ",", 
     "4.197156584694993`", ",", "4.000823843093983`", ",", 
     "4.136050070561115`", ",", "4.0075244898139815`", ",", 
     "4.687824470152398`", ",", "4.06421622292376`", ",", 
     "4.332446352822089`", ",", "4.140038203896858`", ",", 
     "4.040422915462141`", ",", "4.639691995445573`", ",", 
     "4.290219830321672`", ",", "4.165720435866628`", ",", 
     "4.106697304631308`", ",", "4.228501536701415`", ",", 
     "4.449696839180262`", ",", "4.058567499746204`", ",", 
     "4.01094223757957`", ",", "4.068106836387477`", ",", 
     "4.014623564514924`", ",", "4.133235587137833`", ",", 
     "4.178348529459511`", ",", "5.053200273604762`", ",", 
     "4.143326810767182`"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.526921951405532*^9, 3.5269219602415323`*^9}, {
  3.5269220203686037`*^9, 3.5269220282083874`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EstimatedDistribution", "[", 
  RowBox[{"data", ",", 
   RowBox[{"TruncatedDistribution", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", "\[Infinity]"}], "}"}], ",", 
     RowBox[{"NormalDistribution", "[", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.526922030853652*^9, 3.526922041542721*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedDistribution", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4.000823662750104`", ",", "\[Infinity]"}], "}"}], ",", 
   RowBox[{"NormalDistribution", "[", 
    RowBox[{"0", ",", "1"}], "]"}]}], "]"}]], "Output",
 CellChangeTimes->{3.5269220435579224`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Random number generation", "Subsection",
 CellChangeTimes->{{3.5272647707610655`*^9, 3.5272647764003887`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomVariate", "[", 
   RowBox[{
    RowBox[{"TruncatedDistribution", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.5", ",", "\[Infinity]"}], "}"}], ",", 
      RowBox[{"NormalDistribution", "[", "]"}]}], "]"}], ",", "10"}], "]"}], "//",
   "AbsoluteTiming"}]], "Input",
 CellChangeTimes->{{3.5272647909422197`*^9, 3.527264802030854*^9}}],

Cell["\<\
It\[CloseCurlyQuote]s slow at extreme tails, though:\
\>", "Text",
 CellChangeTimes->{{3.5272647188800983`*^9, 3.5272647827987547`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomVariate", "[", 
   RowBox[{
    RowBox[{"TruncatedDistribution", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"4", ",", "\[Infinity]"}], "}"}], ",", 
      RowBox[{"NormalDistribution", "[", "]"}]}], "]"}], ",", "10"}], "]"}], "//",
   "AbsoluteTiming"}]], "Input",
 CellChangeTimes->{{3.5269222090944743`*^9, 3.5269222221427794`*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Crafting TruncatedNormalDi\[Ellipsis]", "Section",
 CellChangeTimes->{{3.526922104219988*^9, 3.5269221135939255`*^9}, {
  3.526926243700904*^9, 3.5269262622177553`*^9}, {3.527251914027815*^9, 
  3.527251916112815*^9}, {3.5272527073078127`*^9, 3.527252710119094*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "TruncatedNormalDistribution", "]"}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5269239418347254`*^9, 3.5269239444707255`*^9}}],

Cell[CellGroupData[{

Cell["Bare bone", "Subsection",
 CellChangeTimes->{{3.526922304827047*^9, 3.5269223067812424`*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedNormalDistribution", "/:", "\[IndentingNewLine]", 
  RowBox[{"DistributionParameterAssumptions", "[", 
   RowBox[{"TruncatedNormalDistribution", "[", "r_", "]"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"r", "\[Element]", "Reals"}], "&&", 
   RowBox[{"r", ">", "0"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5269224761441765`*^9, 3.526922490340596*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedNormalDistribution", "/:", "\[IndentingNewLine]", 
  RowBox[{"DistributionParameterQ", "[", 
   RowBox[{"e", ":", 
    RowBox[{"TruncatedNormalDistribution", "[", "r_", "]"}]}], "]"}], ":=", 
  RowBox[{"Or", "[", 
   RowBox[{
    RowBox[{"!", 
     RowBox[{"NumericQ", "[", "r", "]"}]}], ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Positive", "[", "r", "]"}], "=!=", "False"}], ")"}], ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Message", "[", 
       RowBox[{
        RowBox[{"TruncatedNormalDistribution", "::", "posprm"}], ",", "r", 
        ",", "1", ",", 
        RowBox[{"HoldForm", "[", "e", "]"}]}], "]"}], ";", "False"}], ")"}]}],
    "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5269222372672915`*^9, 3.526922354599024*^9}, {
  3.5269224233548985`*^9, 3.526922469667529*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedNormalDistribution", "/:", "\[IndentingNewLine]", 
  RowBox[{"Statistics`Library`DistributionNParameterQ", "[", 
   RowBox[{"e", ":", 
    RowBox[{"TruncatedNormalDistribution", "[", "r_", "]"}]}], "]"}], ":=", 
  RowBox[{"Or", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"NumericQ", "[", "r", "]"}], "&&", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Positive", "[", "r", "]"}], "===", "True"}], ")"}]}], ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Message", "[", 
       RowBox[{
        RowBox[{"TruncatedNormalDistribution", "::", "posprm"}], ",", "r", 
        ",", "1", ",", 
        RowBox[{"HoldForm", "[", "e", "]"}]}], "]"}], ";", "False"}], ")"}]}],
    "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5269261592454596`*^9, 3.5269261796264973`*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedNormalDistribution", "/:", 
  RowBox[{"DistributionDomain", "[", 
   RowBox[{
    RowBox[{"TruncatedNormalDistribution", "[", "r_", "]"}], "?", 
    "DistributionParameterQ"}], "]"}], ":=", 
  RowBox[{"Interval", "[", 
   RowBox[{"{", 
    RowBox[{"r", ",", "Infinity"}], "}"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5269227546570253`*^9, 3.5269227681033697`*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedNormalDistribution", "/:", 
  RowBox[{"PDF", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"TruncatedNormalDistribution", "[", "r_", "]"}], "?", 
     "DistributionParameterQ"}], ",", "x_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Function", "[", 
    RowBox[{"z", ",", 
     RowBox[{"Piecewise", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"2", "/", "Pi"}], "]"}], 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"z", "^", "2"}]}], "/", "2"}], "]"}], "/", 
           RowBox[{"Erfc", "[", 
            RowBox[{"r", "/", 
             RowBox[{"Sqrt", "[", "2", "]"}]}], "]"}]}]}], ",", 
         RowBox[{"z", ">", "r"}]}], "}"}], "}"}], "]"}], ",", "Listable"}], 
    "]"}], "[", "x", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526922835871146*^9, 3.5269229078223405`*^9}, {
  3.526923888300726*^9, 3.5269239072687254`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Select moments", "Subsection",
 CellChangeTimes->{{3.5269227762301826`*^9, 3.526922777146274*^9}, {
  3.527264955072608*^9, 3.527264958970831*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedNormalDistribution", "/:", "\[IndentingNewLine]", 
  RowBox[{"Mean", "[", 
   RowBox[{
    RowBox[{"TruncatedNormalDistribution", "[", "r_", "]"}], "?", 
    "DistributionParameterQ"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{" ", 
     SqrtBox[
      FractionBox["2", "\[Pi]"]]}], 
    RowBox[{"Erfc", "[", 
     FractionBox["r", 
      SqrtBox["2"]], "]"}]], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["r", "2"], "2"]}]]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526922543954957*^9, 3.526922563625924*^9}, {
  3.5269226272772884`*^9, 3.5269226363271933`*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedNormalDistribution", "/:", "\[IndentingNewLine]", 
  RowBox[{"Variance", "[", 
   RowBox[{
    RowBox[{"TruncatedNormalDistribution", "[", "r_", "]"}], "?", 
    "DistributionParameterQ"}], "]"}], ":=", 
  RowBox[{"1", "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       SuperscriptBox["r", "2"]}]]}], 
    RowBox[{"\[Pi]", " ", 
     SuperscriptBox[
      RowBox[{"Erfc", "[", 
       FractionBox["r", 
        SqrtBox["2"]], "]"}], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["r", "2"], "2"]}]], " ", 
     SqrtBox[
      FractionBox["2", "\[Pi]"]], " ", "r"}], 
    RowBox[{"Erfc", "[", 
     FractionBox["r", 
      SqrtBox["2"]], "]"}]]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526922543954957*^9, 3.526922563625924*^9}, {
  3.5269226272772884`*^9, 3.5269226363271933`*^9}, {3.526922687627323*^9, 
  3.5269227132348833`*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedNormalDistribution", "/:", "\[IndentingNewLine]", 
  RowBox[{"StandardDeviation", "[", 
   RowBox[{
    RowBox[{"TruncatedNormalDistribution", "[", "r_", "]"}], "?", 
    "DistributionParameterQ"}], "]"}], ":=", 
  SqrtBox[
   RowBox[{"1", "-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        SuperscriptBox["r", "2"]}]]}], 
     RowBox[{"\[Pi]", " ", 
      SuperscriptBox[
       RowBox[{"Erfc", "[", 
        FractionBox["r", 
         SqrtBox["2"]], "]"}], "2"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["r", "2"], "2"]}]], " ", 
      SqrtBox[
       FractionBox["2", "\[Pi]"]], " ", "r"}], 
     RowBox[{"Erfc", "[", 
      FractionBox["r", 
       SqrtBox["2"]], "]"}]]}]]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526922543954957*^9, 3.526922563625924*^9}, {
  3.5269226272772884`*^9, 3.5269226363271933`*^9}, {3.526922687627323*^9, 
  3.5269227132348833`*^9}, {3.526922787169276*^9, 3.5269227916657257`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Random number generation", "Subsection",
 CellChangeTimes->{{3.526922924692027*^9, 3.5269229285554132`*^9}}],

Cell["\<\
Transformed density rejection method is used:\
\>", "Text",
 CellChangeTimes->{{3.527252537492833*^9, 3.527252550573141*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedNormalDistribution", "/:", 
  RowBox[{"Random`DistributionVector", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"TruncatedNormalDistribution", "[", "r_", "]"}], "?", 
     "DistributionParameterQ"}], ",", " ", "len_Integer", ",", "prec_"}], 
   "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"NumericQ", "[", "r", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Random`RandomRealTDR", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Function", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"x", "^", "2"}]}], "/", "2"}]}], "]"}], ",", 
        RowBox[{"Function", "[", 
         RowBox[{"x", ",", 
          RowBox[{"-", "x"}]}], "]"}], ",", "\"\<Transformed\>\""}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "Infinity"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"N", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"r", "+", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"r", "+", "1"}], ",", 
            RowBox[{"r", "+", 
             RowBox[{"3", "/", "2"}]}]}], "}"}], ",", "prec"}], "]"}]}], 
       "}"}], ",", "len", ",", "prec"}], "]"}], "\[IndentingNewLine]", ",", 
    "$Failed"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.526922937354293*^9, 3.5269230469962564`*^9}, {
  3.5269238099217253`*^9, 3.5269238252477255`*^9}, {3.52725258056614*^9, 
  3.527252584781562*^9}}],

Cell["\<\
The method is explained in the parent workshop notebook.\
\>", "Text",
 CellChangeTimes->{{3.5272525540784917`*^9, 3.527252575916675*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Remaing property fall back on TruncatedDistribution", "Subsection",
 CellChangeTimes->{{3.5269230547860355`*^9, 3.526923072923849*^9}, {
  3.527264944988031*^9, 3.527264945250046*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedNormalDistribution", "/:", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"f", ":", 
     RowBox[{"(", 
      RowBox[{
      "CDF", "|", "SurvivalFunction", "|", "HazardFunction", "|", "Skewness", 
       "|", "Kurtosis", "|", "Quantile", "|", "InverseCDF", "|", 
       "InverseSurvivalFunction", "|", "Median", "|", "Likelihood", "|", 
       "LogLikelihood", "|", "CharacteristicFunction", "|", "Moment", "|", 
       "CentralMoment", "|", "FactorialMoment", "|", "Cumulant", "|", 
       "MomentGeneratingFunction", "|", "CumulantGeneratingFunction", "|", 
       "CentralMomentGeneratingFunction", "|", 
       "FactorialMomentGeneratingFunction"}], ")"}]}], ")"}], "[", 
   RowBox[{
    RowBox[{
     RowBox[{"TruncatedNormalDistribution", "[", "r_", "]"}], "?", 
     "DistributionParameterQ"}], ",", "arg___"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "res", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"res", "=", 
      RowBox[{"f", "[", 
       RowBox[{
        RowBox[{"TruncatedDistribution", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"r", ",", "Infinity"}], "}"}], ",", 
          RowBox[{"NormalDistribution", "[", "]"}]}], "]"}], ",", "arg"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"res", "/;", 
      RowBox[{
       RowBox[{"Head", "[", "res", "]"}], "=!=", "f"}]}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5269230750250587`*^9, 3.526923144268983*^9}, {
  3.526923189229478*^9, 3.5269233071452684`*^9}, {3.5269234321687255`*^9, 
  3.5269234831457253`*^9}, {3.526924105218077*^9, 3.5269241097535305`*^9}}],

Cell["\<\
The following code is part of parameter estimation framework, and tells if \
the data could ever have come from this distribution:\
\>", "Text",
 CellChangeTimes->{{3.527252592236307*^9, 3.5272526419442773`*^9}}],

Cell[BoxData[
 RowBox[{"TruncatedNormalDistribution", "/:", 
  RowBox[{"Statistics`Library`AcceptableDistributedDataQ", "[", 
   RowBox[{
    RowBox[{"TruncatedNormalDistribution", "[", "r_", "]"}], ",", "data_"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"VectorQ", "[", 
    RowBox[{"data", ",", "NumberQ"}], "]"}], "&&", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Min", "[", "data", "]"}], ">", "0"}], ")"}], "===", 
    "True"}]}]}]], "Input",
 CellChangeTimes->{{3.526925726857225*^9, 3.5269257642619653`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Subsection",
 CellChangeTimes->{{3.526983113420315*^9, 3.526983116277457*^9}}],

Cell["\<\
This line will not be needed in the future versions.\
\>", "Text",
 CellChangeTimes->{{3.5269831205531673`*^9, 3.526983174992934*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
   "Statistics`Library`BuiltInDistributionHeadQ", "[", 
    "TruncatedNormalDistribution", "]"}], "^=", "True"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5269236417027254`*^9, 3.5269236524857254`*^9}, {
  3.5269246981943693`*^9, 3.526924703864936*^9}}],

Cell["\<\
Currently it is needed for some solvers to start working on it.\
\>", "Text",
 CellChangeTimes->{{3.527252434712556*^9, 3.5272524628723717`*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using it", "Section",
 CellChangeTimes->{{3.5269257808686256`*^9, 3.526925783823921*^9}}],

Cell[BoxData[
 RowBox[{"Cumulant", "[", 
  RowBox[{
   RowBox[{"TruncatedNormalDistribution", "[", "4.5", "]"}], ",", "6"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5269233691204653`*^9, 3.5269234046720204`*^9}, {
  3.5269234918427258`*^9, 3.5269235170587254`*^9}, {3.5269235508777256`*^9, 
  3.5269235620607257`*^9}, {3.5269257938079195`*^9, 3.5269257980653453`*^9}, {
  3.5272648713558197`*^9, 3.5272648841225495`*^9}}],

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"sample", "=", 
    RowBox[{"RandomVariate", "[", 
     RowBox[{
      RowBox[{"TruncatedNormalDistribution", "[", "4", "]"}], ",", 
      RowBox[{"10", "^", "5"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.5269236626907253`*^9, 3.5269236816037254`*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Histogram", "[", 
    RowBox[{"sample", ",", "75", ",", "\"\<PDF\>\""}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"PDF", "[", 
      RowBox[{
       RowBox[{"TruncatedNormalDistribution", "[", "4", "]"}], ",", "x"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "4", ",", "6"}], "}"}], ",", 
     RowBox[{"Evaluated", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.526923684038726*^9, 3.5269236846007257`*^9}, {
   3.5269237721477256`*^9, 3.526923788776726*^9}, {3.526923847057726*^9, 
   3.5269238585357256`*^9}, 3.5269239219807253`*^9}],

Cell[BoxData[
 RowBox[{"EstimatedDistribution", "[", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{"sample", ",", "100"}], "]"}], ",", 
   RowBox[{"TruncatedDistribution", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", "Infinity"}], "}"}], ",", 
     RowBox[{"NormalDistribution", "[", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5269239796647253`*^9, 3.5269240084947257`*^9}, {
  3.52692404323888*^9, 3.5269240512826843`*^9}, {3.526924130160571*^9, 
  3.5269241327428293`*^9}}],

Cell[BoxData[
 RowBox[{"EstimatedDistribution", "[", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{"sample", ",", "100"}], "]"}], ",", 
   RowBox[{"TruncatedNormalDistribution", "[", "r", "]"}], ",", 
   RowBox[{"ParameterEstimator", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<MaximumLikelihood\>\"", ",", 
      RowBox[{"Method", "\[Rule]", "\"\<NMaximize\>\""}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5269239796647253`*^9, 3.5269240084947257`*^9}, {
  3.52692404323888*^9, 3.5269240512826843`*^9}, {3.526924130160571*^9, 
  3.5269241418227377`*^9}, {3.5269247840339518`*^9, 3.52692481261481*^9}, {
  3.5269258260871468`*^9, 3.5269258468782263`*^9}}],

Cell[BoxData[
 RowBox[{"RandomVariate", "[", 
  RowBox[{
   RowBox[{"TransformedDistribution", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "^", "2"}], "+", 
      RowBox[{"y", "^", "2"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Distributed]", 
        RowBox[{"TruncatedNormalDistribution", "[", "1", "]"}]}], ",", 
       RowBox[{"y", "\[Distributed]", 
        RowBox[{"TruncatedNormalDistribution", "[", "1", "]"}]}]}], "}"}]}], 
    "]"}], ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.5269258616967077`*^9, 3.526925908366374*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{863, 817},
WindowMargins->{{480, Automatic}, {Automatic, 32}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell["Style Environment Names", "Section"], 
      Cell[
       StyleData[All, "Condensed"], MenuSortingValue -> None], 
      Cell[
       StyleData[All, "SlideShow"], DockedCells -> {
         FEPrivate`FrontEndResource["FEExpressions", "SlideshowToolbar"], 
         Cell[
          BoxData[
           GraphicsBox[
            TagBox[
             RasterBox[CompressedData["
1:eJzt3U9oXGe65/HAgEBSIVllV1UQjkEkyGAnYNyy2w43ThzjONyOO3YTbDqI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              "], {{0, 90}, {2400, 0}}, {0, 255}, ColorFunction -> RGBColor], 
             BoxForm`ImageTag[
             "Byte", ColorSpace -> "RGB", Interleaving -> True], Selectable -> 
             False], BaseStyle -> "ImageGraphics", ImageSize -> 
            Magnification[1], ImageSizeRaw -> {2400, 90}, 
            PlotRange -> {{0, 2400}, {0, 90}}]], "", CellMargins -> 0, 
          CellChangeTimes -> {{3.516548605022827*^9, 3.516548633085456*^9}, {
            3.516616961864057*^9, 3.516616982571135*^9}, 
            3.518187891728025*^9, {3.518199033657151*^9, 
            3.5181990340305967`*^9}}]}, CellMargins -> 0, 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.739193, 0.750317, 0.747173]}], 
      Cell[
       BoxData[
        GraphicsBox[
         TagBox[
          RasterBox[CompressedData["
1:eJzt3U9oXGe65/HAgEBSIVllV1UQjkEkyGAnYNyy2w43ThzjONyOO3YTbDqI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           "], {{0, 90}, {2400, 0}}, {0, 255}, ColorFunction -> RGBColor], 
          BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
           Selectable -> False], BaseStyle -> "ImageGraphics", ImageSize -> 
         Magnification[1], ImageSizeRaw -> {2400, 90}, 
         PlotRange -> {{0, 2400}, {0, 90}}]], "", CellMargins -> 0, 
       CellChangeTimes -> {{3.516548605022827*^9, 3.516548633085456*^9}, {
         3.516616961864057*^9, 3.516616982571135*^9}, 3.518187891728025*^9, {
         3.518199033657151*^9, 3.5181990340305967`*^9}}], 
      Cell[
       BoxData[
        RowBox[{
          RowBox[{"(*", 
            
            RowBox[{"Evaluate", " ", "the", " ", "following", " ", "to", " ", 
              "copy", " ", "the", " ", "style", " ", "of", " ", "the", " ", 
              "cell", " ", "above", " ", "into", " ", "\[IndentingNewLine]", 
              "the", " ", "docked", " ", "cell", " ", "style", " ", "of", " ", 
              RowBox[{"the", " ", "'"}], 
              RowBox[{"Notebook", "'"}], " ", "definition", " ", 
              RowBox[{"(", 
                RowBox[{"2", " ", "cells", " ", "above"}], ")"}], " ", 
              "\[IndentingNewLine]", "These", " ", "two", " ", "cell", " ", 
              "can", " ", "be", " ", "removed", " ", "once", " ", "the", " ", 
              "docked", " ", "cell", " ", "is", " ", 
              RowBox[{"created", "."}]}], "\[IndentingNewLine]", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              RowBox[{"SelectionMove", "[", 
                RowBox[{
                  RowBox[{"SelectedNotebook", "[", "]"}], ",", "Previous", 
                  ",", "Cell", ",", "2"}], "]"}], ";"}], 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"celldata", "=", 
                RowBox[{"NotebookRead", "[", 
                  RowBox[{"SelectedNotebook", "[", "]"}], "]"}]}], ";"}], 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"SelectionMove", "[", 
                RowBox[{
                  RowBox[{"SelectedNotebook", "[", "]"}], ",", "Previous", 
                  ",", "Cell", ",", "1"}], "]"}], ";"}], 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"SetOptions", "[", 
                RowBox[{
                  RowBox[{"NotebookSelection", "[", 
                    RowBox[{"SelectedNotebook", "[", "]"}], "]"}], ",", 
                  RowBox[{"DockedCells", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"FEPrivate`FrontEndResource", "[", 
                    
                    RowBox[{
                    "\"FEExpressions\"", ",", "\"SlideshowToolbar\""}], "]"}],
                     ",", "celldata"}], "}"}]}]}], "]"}], ";"}]}]}]], "Input",
        FontWeight -> "Bold"]}, Open]], 
   Cell[
    CellGroupData[{
      Cell["Notebook Options Settings", "Section"], 
      Cell[
       StyleData["Notebook"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.739193, 0.750317, 0.747173]}]}, Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Title and Section Cells", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], ShowCellBracket -> Automatic, ShowGroupOpener -> 
          False, CellMargins -> {{48, 0}, {30, 0}}, 
          CellBracketOptions -> {"Margins" -> {0, 0}}, 
          CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> False, 
          CellFrameMargins -> {{20, 20}, {20, 20}}, DefaultNewInlineCellStyle -> 
          "None", InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, 
          CellChangeTimes -> {3.479211616867702*^9, 3.483202458952606*^9}, 
          TextAlignment -> Left, LineSpacing -> {1, 0}, LanguageCategory -> 
          "NaturalLanguage", CounterIncrements -> "Title", 
          CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
            "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontFamily -> 
          "Helvetica", FontSize -> 48, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> "Plain", 
          FontVariations -> {
           "Masked" -> False, "Outline" -> False, "Shadow" -> False, 
            "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
          RGBColor[
           0.8156862745098039, 0.07058823529411765, 0.07058823529411765], 
          Background -> None], 
         Cell[
          StyleData["Title", "Presentation", StyleDefinitions -> None], 
          CellMargins -> {{55, 3}, {14, 125}}, LineSpacing -> {1, 5}, 
          FontSize -> 28], 
         Cell[
          StyleData[
          "Title", "SlideShow", StyleDefinitions -> 
           StyleData["Title", "Presentation"]], 
          CellMargins -> {{55, 3}, {14, 35}}, FontSize -> 55], 
         Cell[
          StyleData["Title", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{2, 0}, {0, 10}}, LineSpacing -> {1, 18}, FontSize -> 
          15]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subtitle"], ShowCellBracket -> False, 
          CellMargins -> {{58, 0}, {0, 5}}, 
          CellBracketOptions -> {"Margins" -> {0, 0}}, 
          CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> False,
           DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, TextAlignment -> Left, LanguageCategory -> 
          "NaturalLanguage", CounterIncrements -> "Subtitle", 
          CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
            "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
          FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> 
          RGBColor[
           0.34901960784313724`, 0.5254901960784314, 0.5176470588235295], 
          Background -> None], 
         Cell[
          StyleData["Subtitle", "Presentation", StyleDefinitions -> None], 
          CellMargins -> {{58, 0}, {0, 5}}, FontSize -> 20], 
         Cell[
          StyleData[
          "Subtitle", "SlideShow", StyleDefinitions -> 
           StyleData["Subtitle", "Presentation"]]], 
         Cell[
          StyleData["Subtitle", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{2, 0}, {0, 5}}, FontSize -> 14, Background -> 
          GrayLevel[1]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubtitle", StyleDefinitions -> StyleData["Subtitle"]],
           FontSize -> Inherited + 3], 
         Cell[
          StyleData["Subsubtitle", "Presentation"], FontSize -> 
          Inherited + 3], 
         Cell[
          StyleData[
          "Subsubtitle", "SlideShow", StyleDefinitions -> 
           StyleData["Subsubtitle", "Presentation"]]], 
         Cell[
          StyleData["Subsubtitle", "Printout"], FontSize -> Inherited + 0]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0.2, 0}}, 
          ShowGroupOpener -> False, CellMargins -> {{50, 50}, {10, 25}}, 
          FontSize -> 36, FontWeight -> "Plain", FontColor -> 
          RGBColor[
           0.8156862745098039, 0.07058823529411765, 0.07058823529411765]], 
         Cell[
          StyleData["Section", "Presentation"], 
          CellFrame -> {{0, 0}, {0.2, 0}}, 
          CellMargins -> {{58, 50}, {10, 35}}], 
         Cell[
          StyleData[
          "Section", "SlideShow", StyleDefinitions -> 
           StyleData["Section", "Presentation"]], 
          CellMargins -> {{58, 50}, {10, 35}}], 
         Cell[
          StyleData["Section", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {7, 22}}, FontSize -> 14]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellDingbat -> None, ShowGroupOpener -> 
          True, CellMargins -> {{65, Inherited}, {0, 12}}, 
          CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
          False, DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, LanguageCategory -> "NaturalLanguage", 
          CounterIncrements -> "Subsection", 
          CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
          "Helvetica", FontSize -> 24, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> 
          RGBColor[
           0.34901960784313724`, 0.5254901960784314, 0.5176470588235295]], 
         Cell[
          StyleData["Subsection", "Presentation"], 
          CellMargins -> {{60, 50}, {6, 15}}, LineSpacing -> {1, 0}, 
          FontFamily -> "Helvetica"], 
         Cell[
          StyleData["Subsection", "SlideShow"], 
          CellMargins -> {{60, 50}, {8, 12}}, LineSpacing -> {1, 0}, 
          FontFamily -> "Helvetica"], 
         Cell[
          StyleData["Subsection", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {2, 22}}, FontSize -> 12]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], CellDingbat -> None, ShowGroupOpener -> 
          True, CellMargins -> {{80, Inherited}, {0, 12}}, 
          CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
          False, DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, LanguageCategory -> "NaturalLanguage", 
          CounterIncrements -> "Subsubsection", FontFamily -> "Helvetica", 
          FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> RGBColor[0.279216, 0.420392, 0.414118]], 
         Cell[
          StyleData["Subsubsection", "Presentation"], 
          CellMargins -> {{60, 50}, {6, 20}}, LineSpacing -> {1, 0}], 
         Cell[
          StyleData[
          "Subsubsection", "SlideShow", StyleDefinitions -> 
           StyleData["Subsubsection", "Presentation"]]], 
         Cell[
          StyleData["Subsubsection", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {2, 22}}, FontSize -> 11]}, Open]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Body Text", "Section"], 
      Cell[
       CellGroupData[{
         Cell["Standard", "Subsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{60, 10}, {7, 7}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 3}, CounterIncrements -> "Text",
              FontFamily -> "Helvetica", FontSize -> 17], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{60, 50}, {10, 10}}, FontSize -> 17], 
            Cell[
             StyleData[
             "Text", "SlideShow", StyleDefinitions -> 
              StyleData["Text", "Presentation"]]], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{2, 2}, {6, 6}}, 
             TextJustification -> 0.5, Hyphenation -> True, FontSize -> 10]}, 
           Open]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Display", "Subsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> 
             Cell["\[FilledSmallCircle]", FontWeight -> "Bold"], 
             CellMargins -> {{84, 10}, {7, 7}}, ReturnCreatesNewCell -> True, 
             CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
             CounterIncrements -> "Item"], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{124, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "Item", "SlideShow", StyleDefinitions -> 
              StyleData["Item", "Presentation"]]], 
            Cell[
             StyleData["Item", "Printout"], CellMargins -> {{2, 2}, {0, 6}}]},
            Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem", StyleDefinitions -> StyleData["Item"]], 
             CellMargins -> {{108, 10}, {7, 7}}, ReturnCreatesNewCell -> True,
              CellGroupingRules -> {"GroupTogetherNestedGrouping", 15150}, 
             CounterIncrements -> "Subitem"], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{146, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "Subitem", "SlideShow", StyleDefinitions -> 
              StyleData["Subitem", "Presentation"]]], 
            Cell[
             StyleData["Subitem", "Printout"], 
             CellMargins -> {{30, 2}, {0, 6}}]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered", StyleDefinitions -> StyleData["Text"]],
              CellDingbat -> Cell[
               TextData[{
                 CounterBox["ItemNumbered"], "."}]], 
             CellMargins -> {{84, 10}, {7, 7}}, ReturnCreatesNewCell -> True, 
             CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
             CounterIncrements -> "ItemNumbered"], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{124, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "ItemNumbered", "SlideShow", StyleDefinitions -> 
              StyleData["ItemNumbered", "Presentation"]]], 
            Cell[
             StyleData["ItemNumbered", "Printout"], 
             CellMargins -> {{2, 2}, {0, 6}}]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "SubitemNumbered", StyleDefinitions -> 
              StyleData["ItemNumbered"]], CellDingbat -> Cell[
               TextData[{
                 CounterBox["SubitemNumbered", CounterFunction :> (Part[
                    CharacterRange["a", "z"], #]& )], "."}]], 
             CellMargins -> {{108, 10}, {7, 7}}, ReturnCreatesNewCell -> True,
              CellGroupingRules -> {"GroupTogetherNestedGrouping", 15150}, 
             CounterIncrements -> "SubitemNumbered"], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{146, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "SubitemNumbered", "SlideShow", StyleDefinitions -> 
              StyleData["SubitemNumbered", "Presentation"]]], 
            Cell[
             StyleData["SubitemNumbered", "Printout"], 
             CellMargins -> {{30, 2}, {0, 6}}]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "ItemParagraph", StyleDefinitions -> StyleData["Item"]], 
             CellDingbat -> None, CellMargins -> {{84, 10}, {7, 7}}, 
             ReturnCreatesNewCell -> True, 
             CellGroupingRules -> {"GroupTogetherNestedGrouping", 15100}, 
             CounterIncrements -> "ItemParagraph"], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{124, 10}, {7, 7}}], 
            Cell[
             StyleData[
             "ItemParagraph", "SlideShow", StyleDefinitions -> 
              StyleData["ItemParagraph", "Presentation"]]], 
            Cell[
             StyleData["ItemParagraph", "Printout"], 
             CellMargins -> {{14, 2}, {0, 6}}]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "SubitemParagraph", StyleDefinitions -> StyleData["Subitem"]], 
             CellDingbat -> None, ReturnCreatesNewCell -> True, 
             CellGroupingRules -> {"GroupTogetherNestedGrouping", 15200}, 
             CounterIncrements -> "SubitemParagraph"], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"]], 
            Cell[
             StyleData[
             "SubitemParagraph", "SlideShow", StyleDefinitions -> 
              StyleData["SubitemParagraph", "Presentation"]]], 
            Cell[
             StyleData["SubitemParagraph", "Printout"]]}, Open]]}, Open]]}, 
     Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Formulas and Programming", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"]], 
         Cell[
          StyleData["DisplayFormula", "Presentation"], 
          CellMargins -> {{60, Inherited}, {Inherited 1.5, Inherited 1.5}}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "DisplayFormula", "SlideShow", StyleDefinitions -> 
           StyleData["DisplayFormula", "Presentation"]]], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, FontSize -> 
          10]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}]]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered"], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Presentation"], 
          CellMargins -> {{60, Inherited}, {Inherited 1.5, Inherited 1.5}}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "DisplayFormulaNumbered", "SlideShow", StyleDefinitions -> 
           StyleData["DisplayFormulaNumbered", "Presentation"]]], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{39, Inherited}, {Inherited, Inherited}}]}, Open]]},
      Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Inline Formatting", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InlineFormula"]], 
         Cell[
          StyleData["InlineFormula", "Presentation"], FontSize -> 17], 
         Cell[
          StyleData[
          "InlineFormula", "SlideShow", StyleDefinitions -> 
           StyleData["InlineFormula", "Presentation"]]], 
         Cell[
          StyleData["InlineFormula", "Printout"]]}, Open]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Input and Output Cells", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], ShowCellBracket -> True, 
          CellMargins -> {{103, 10}, {5, 7}}, 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.734936, 0.713848, 0.694041]}, Evaluatable -> 
          True, CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
          True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
          DefaultFormatType -> DefaultInputFormatType, 
          "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
          FormatType -> InputForm, ShowStringCharacters -> True, NumberMarks -> 
          True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, 
          CounterIncrements -> "Input", FontWeight -> "Bold"], 
         Cell[
          StyleData["Input", "Presentation"], 
          CellMargins -> {{110, 50}, {8, 10}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "Input", "SlideShow", StyleDefinitions -> 
           StyleData["Input", "Presentation"]]], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{39, 0}, {4, 6}}, 
          LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], ShowCellBracket -> True, 
          CellMargins -> {{103, 10}, {7, 7}}, 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.734936, 0.713848, 0.694041]}, Evaluatable -> 
          True, CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
          True, DefaultFormatType -> DefaultInputFormatType, 
          "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
          FormatType -> InputForm, ShowStringCharacters -> True, NumberMarks -> 
          True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, 
          CounterIncrements -> "Input", MenuSortingValue -> 1550, FontWeight -> 
          "Bold"], 
         Cell[
          StyleData["InputOnly", "Presentation"], 
          CellMargins -> {{110, Inherited}, {8, 10}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "InputOnly", "SlideShow", StyleDefinitions -> 
           StyleData["InputOnly", "Presentation"]]], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{39, 0}, {4, 6}}, 
          LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], ShowCellBracket -> True, 
          CellMargins -> {{103, 10}, {7, 5}}, 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.734936, 0.713848, 0.694041]}, 
          CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping", 
          CellHorizontalScrolling -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, DefaultFormatType -> 
          DefaultOutputFormatType, "TwoByteSyntaxCharacterAutoReplacement" -> 
          True, HyphenationOptions -> {
           "HyphenationCharacter" -> "\[Continuation]"}, 
          AutoItalicWords -> {}, LanguageCategory -> None, FormatType -> 
          InputForm, CounterIncrements -> "Output"], 
         Cell[
          StyleData["Output", "Presentation"], 
          CellMargins -> {{110, 50}, {10, 8}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "Output", "SlideShow", StyleDefinitions -> 
           StyleData["Output", "Presentation"]]], 
         Cell[
          StyleData["Output", "Printout"], CellMargins -> {{39, 0}, {6, 4}}, 
          FontSize -> 9]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Code"], CellMargins -> {{103, 10}, {5, 10}}], 
         Cell[
          StyleData["Code", "Presentation"], 
          CellMargins -> {{110, 50}, {8, 10}}, LineSpacing -> {1, 0}, 
          FontSize -> 17], 
         Cell[
          StyleData[
          "Code", "SlideShow", StyleDefinitions -> 
           StyleData["Code", "Presentation"]]], 
         Cell[
          StyleData["Code", "Printout"], CellMargins -> {{39, 0}, {4, 6}}, 
          LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], 
          CellMargins -> {{103, Inherited}, {Inherited, Inherited}}, FontSize -> 
          14], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{70, Inherited}, {Inherited 1.5, Inherited 1.5}}, 
          FontSize -> 17, Magnification -> Inherited 1.5], 
         Cell[
          StyleData[
          "Print", "SlideShow", StyleDefinitions -> 
           StyleData["Print", "Presentation"]]], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{39, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "WolframAlphaShortInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{98, 10}, {5, 7}}, EvaluationMode -> 
          "WolframAlphaShort", 
          CellEventActions -> {"ReturnKeyDown" :> FrontEndTokenExecute[
              EvaluationNotebook[], "HandleShiftReturn"]}, 
          CellFrameLabels -> {{
             Cell[
              BoxData[
               DynamicBox[
                FEPrivate`FrontEndResource["WABitmaps", "Equal"]]], 
              CellBaseline -> Baseline], None}, {None, None}}, FormatType -> 
          TextForm, FontFamily -> "Helvetica"], 
         Cell[
          StyleData["WolframAlphaShortInput", "Presentation"], 
          CellMargins -> {{107, 50}, {8, 10}}], 
         Cell[
          StyleData[
          "WolframAlphaShortInput", "SlideShow", StyleDefinitions -> 
           StyleData["WolframAlphaShortInput", "Presentation"]]], 
         Cell[
          StyleData["WolframAlphaShortInput", "Printout"], 
          CellFrameLabelMargins -> 3]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "WolframAlphaLong", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{100, 10}, {5, 7}}, 
          StyleKeyMapping -> {
           "=" -> "Input", "Backspace" -> "WolframAlphaShort"}, 
          EvaluationMode -> "WolframAlphaLong", 
          CellEventActions -> {"ReturnKeyDown" :> FrontEndTokenExecute[
              EvaluationNotebook[], "HandleShiftReturn"]}, 
          CellFrameLabels -> {{
             Cell[
              BoxData[
               DynamicBox[
                FEPrivate`FrontEndResource["WABitmaps", "SpikeyEqual"]]]], 
             None}, {None, None}}, DefaultFormatType -> TextForm, FormatType -> 
          TextForm, FontFamily -> "Helvetica"], 
         Cell[
          StyleData["WolframAlphaLong", "Presentation"], 
          CellMargins -> {{107, 50}, {8, 10}}], 
         Cell[
          StyleData[
          "WolframAlphaLong", "SlideShow", StyleDefinitions -> 
           StyleData["WolframAlphaLong", "Presentation"]], 
          CellMargins -> {{107, 50}, {8, 10}}], 
         Cell[
          StyleData["WolframAlphaLong", "Printout"], CellFrameLabelMargins -> 
          3]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Program"], CellMargins -> {{60, 4}, {6, 8}}], 
         Cell[
          StyleData["Program", "Presentation"], 
          CellMargins -> {{60, 50}, {8, 10}}, LineSpacing -> {1, 0}, FontSize -> 
          17], 
         Cell[
          StyleData[
          "Program", "SlideShow", StyleDefinitions -> 
           StyleData["Program", "Presentation"]]], 
         Cell[
          StyleData["Program", "Printout"], FontSize -> 9]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"]], 
         Cell[
          StyleData["CellLabel", "Presentation"], FontSize -> 12], 
         Cell[
          StyleData[
          "CellLabel", "SlideShow", StyleDefinitions -> 
           StyleData["CellLabel", "Presentation"]]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ManipulateLabel"]], 
         Cell[
          StyleData["ManipulateLabel", "Presentation"], FontSize -> 15], 
         Cell[
          StyleData[
          "ManipulateLabel", "SlideShow", StyleDefinitions -> 
           StyleData["ManipulateLabel", "Presentation"]]], 
         Cell[
          StyleData["ManipulateLabel", "Printout"], FontSize -> 8]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GraphicsLabel"]], 
         Cell[
          StyleData["GraphicsLabel", "Presentation"], FontSize -> 14], 
         Cell[
          StyleData[
          "GraphicsLabel", "SlideShow", StyleDefinitions -> 
           StyleData["GraphicsLabel", "Presentation"]]], 
         Cell[
          StyleData["GraphicsLabel", "Printout"], FontSize -> 8]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Graphics3DLabel"]], 
         Cell[
          StyleData["Graphics3DLabel", "Presentation"], FontSize -> 14], 
         Cell[
          StyleData[
          "Graphics3DLabel", "SlideShow", StyleDefinitions -> 
           StyleData["Graphics3DLabel", "Presentation"]]], 
         Cell[
          StyleData["Graphics3DLabel", "Printout"], FontSize -> 8]}, Open]]}, 
     Open]], 
   Cell[
    CellGroupData[{
      Cell[
      "Styles for SlideShow", "Section", 
       CellChangeTimes -> {{3.514665148412793*^9, 3.5146651505550737`*^9}}], 
      Cell[
       StyleData["slideshowheader"], ShowCellBracket -> False, 
       CellMargins -> {{0, 0}, {0, -2}}, Evaluatable -> False, 
       CellHorizontalScrolling -> False, PageBreakBelow -> False, 
       CellFrameMargins -> 0, ImageMargins -> {{0, 0}, {0, 0}}, 
       ImageRegion -> {{0, 1}, {0, 1}}, Magnification -> 1, Background -> 
       GrayLevel[1], CellPadding -> 0, CellFramePadding -> 0], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["hidefromslideshowgraphic"], ShowCellBracket -> False, 
          CellMargins -> {{0, 0}, {0, 0}}, Evaluatable -> False, 
          CellHorizontalScrolling -> False, PageBreakBelow -> False, 
          CellFrameMargins -> 0, ImageMargins -> {{0, 0}, {0, 0}}, 
          ImageRegion -> {{0, 1}, {0, 1}}, Magnification -> 1, Background -> 
          GrayLevel[1], CellPadding -> 0], 
         Cell[
          StyleData["hidefromslideshowgraphic", "SlideShow"], ShowCellBracket -> 
          False, CellElementSpacings -> {
           "CellMinHeight" -> 0, "ClosedCellHeight" -> 0, 
            "ClosedGroupTopMargin" -> 0}, CellOpen -> False, 
          CellHorizontalScrolling -> False]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["slideshowheader2"], ShowCellBracket -> False, 
          CellMargins -> {{0, 0}, {0, 0}}, Evaluatable -> False, 
          CellHorizontalScrolling -> False, PageBreakBelow -> False, 
          ImageMargins -> {{0, 0}, {0, 0}}, ImageRegion -> {{0, 1}, {0, 1}}, 
          Magnification -> 1, Background -> GrayLevel[1]], 
         Cell[
          StyleData["ConferenceGraphicCell", "SlideShow"], ShowCellBracket -> 
          False, CellElementSpacings -> {
           "CellMinHeight" -> 0, "ClosedCellHeight" -> 0, 
            "ClosedGroupTopMargin" -> 0}, CellOpen -> False, 
          CellHorizontalScrolling -> True], 
         Cell[
          StyleData["slideshowheader", "Printout"], FontSize -> 8, 
          Magnification -> 0.75]}, Open]], 
      Cell[
       StyleData[
       "ConferenceGraphicCellSlideShowOnly", StyleDefinitions -> 
        StyleData["ConferenceCellGraphic"]], ShowCellBracket -> False, 
       CellMargins -> 0, 
       CellElementSpacings -> {
        "CellMinHeight" -> 0, "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 
         0}, CellOpen -> False], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SlideShowNavigationBar"], Editable -> True, Selectable -> 
          False, CellFrame -> 0, ShowGroupOpener -> False, 
          CellMargins -> {{0, 0}, {3, 3}}, CellOpen -> True, CellFrameMargins -> 
          0, CellFrameColor -> None, Background -> None], 
         Cell[
          StyleData["SlideShowNavigationBar", "Printout"], PageBreakAbove -> 
          Automatic]}, Open]]}, Open]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Microsoft Windows (64-bit) (February 23, 2011)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 179, 4, 85, "Title"],
Cell[761, 28, 134, 3, 22, "Subsubtitle"],
Cell[CellGroupData[{
Cell[920, 35, 107, 1, 80, "Section"],
Cell[1030, 38, 351, 8, 23, "DisplayFormula"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1418, 51, 121, 1, 80, "Section"],
Cell[CellGroupData[{
Cell[1564, 56, 126, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[1715, 62, 302, 7, 28, "Input"],
Cell[2020, 71, 331, 12, 87, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2388, 88, 355, 8, 28, "Input"],
Cell[2746, 98, 918, 30, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3701, 133, 302, 7, 28, "Input"],
Cell[4006, 142, 358, 12, 47, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4413, 160, 128, 2, 31, "Subsection"],
Cell[4544, 164, 971, 19, 149, "Input"],
Cell[CellGroupData[{
Cell[5540, 187, 346, 8, 28, "Input"],
Cell[5889, 197, 289, 7, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[6227, 210, 116, 1, 31, "Subsection"],
Cell[6346, 213, 386, 10, 28, "Input"],
Cell[6735, 225, 146, 3, 33, "Text"],
Cell[6884, 230, 386, 10, 28, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7319, 246, 272, 3, 80, "Section"],
Cell[7594, 251, 205, 5, 28, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[7824, 260, 99, 1, 39, "Subsection"],
Cell[7926, 263, 405, 8, 49, "Input",
 InitializationCell->True],
Cell[8334, 273, 859, 22, 89, "Input",
 InitializationCell->True],
Cell[9196, 297, 828, 21, 89, "Input",
 InitializationCell->True],
Cell[10027, 320, 427, 10, 69, "Input",
 InitializationCell->True],
Cell[10457, 332, 1041, 29, 49, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[11535, 366, 153, 2, 31, "Subsection"],
Cell[11691, 370, 682, 20, 106, "Input",
 InitializationCell->True],
Cell[12376, 392, 1049, 31, 108, "Input",
 InitializationCell->True],
Cell[13428, 425, 1140, 32, 137, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[14605, 462, 114, 1, 31, "Subsection"],
Cell[14722, 465, 135, 3, 33, "Text"],
Cell[14860, 470, 1550, 42, 129, "Input",
 InitializationCell->True],
Cell[16413, 514, 148, 3, 33, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[16598, 522, 190, 2, 31, "Subsection"],
Cell[16791, 526, 1674, 38, 189, "Input"],
Cell[18468, 566, 222, 4, 55, "Text"],
Cell[18693, 572, 531, 14, 69, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[19261, 591, 101, 1, 31, "Subsection"],
Cell[19365, 594, 144, 3, 33, "Text"],
Cell[19512, 599, 325, 8, 28, "Input",
 InitializationCell->True],
Cell[19840, 609, 155, 3, 33, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20044, 618, 95, 1, 80, "Section"],
Cell[20142, 621, 423, 8, 28, "Input"],
Cell[20568, 631, 387, 9, 69, "Input"],
Cell[20958, 642, 767, 18, 69, "Input"],
Cell[21728, 662, 509, 12, 28, "Input"],
Cell[22240, 676, 676, 14, 49, "Input"],
Cell[22919, 692, 574, 15, 49, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
